/**
 * 
 */
package eu.etaxonomy.taxeditor.datasource.wizard;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.database.CdmDataSource;
import eu.etaxonomy.cdm.database.ICdmDataSource;

/**
 * @author n.hoffmann
 *
 */
public class CdmDataSourcePostgreSQLServerWizardPage extends
		CdmDataSourceCredentialsWizardPage {

	private Text text_port;
	private Text text_server;

	private String server;

	private int port;
	
	protected CdmDataSourcePostgreSQLServerWizardPage(ICdmDataSource dataSource) {
		super("PostgreSQL Server");
		setTitle("PostgreSQL Server");
		setDescription("Enter credentials for PostgreSQL Server database");
		this.setDataSource(dataSource);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.datasource.wizard.CdmDataSourceCredentialsWizardPage#createDatabaseForm()
	 */
	@Override
	public void createDatabaseForm() {
		// Create group composite for location data 
		locationGroup = new Group(composite, SWT.NONE);
		locationGroup.setText("Location");
		locationGroup.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 2, 1));
		GridLayout locationLayout = new GridLayout();
		locationLayout.numColumns = 2;
		locationGroup.setLayout(locationLayout);

		// Create host label
		Label serverLabel = new Label(locationGroup, SWT.NONE);
		serverLabel.setText("Host:");

		// Create host input
		text_server = new Text(locationGroup, SWT.BORDER);
		text_server.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		text_server.addModifyListener(this);

		// Create port label
		Label portLabel = new Label(locationGroup, SWT.NONE);
		portLabel.setText("Port:");

		// Create port input
		text_port = new Text(locationGroup, SWT.BORDER);
		text_port.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		
		text_port.addModifyListener(this);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.datasource.wizard.CdmDataSourceCredentialsWizardPage#updateLocation()
	 */
	@Override
	public void updateLocation() {
		server = text_server.getText();
		try{
			if(! text_port.getText().equals("")){
				port = new Integer(text_port.getText());
				setErrorMessage(null);
			}
		}catch(NumberFormatException e){
			setErrorMessage("Port number contains invalid characters");
		}
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.datasource.wizard.CdmDataSourceCredentialsWizardPage#updateDataSource()
	 */
	@Override
	public void updateDataSource() {
		setDataSource(CdmDataSource.NewPostgreSQLInstance(server,
				database,
				port,
				username,
				password, 
				nomenclaturalCode));
	}
	
	@Override
	public void init() {
		if(getDataSource() != null){
			modifyTextWithoutTriggeringListeners(text_server, this, getDataSource().getServer());
			modifyTextWithoutTriggeringListeners(text_port, this, getDataSource().getPort()+"");			
			super.init();
		}
	}

}
