// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.featuretree;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.eclipse.jface.viewers.CheckboxTableViewer;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;

import eu.etaxonomy.cdm.model.description.Feature;
import eu.etaxonomy.cdm.model.description.FeatureTree;
import eu.etaxonomy.taxeditor.preference.menu.DefinedTermBaseContentProvider;
import eu.etaxonomy.taxeditor.preference.menu.DefinedTermBaseLabelProvider;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>AvailableFeaturesWizardPage class.</p>
 *
 * @author n.hoffmann
 * @created Aug 5, 2010
 * @version 1.0
 */
public class AvailableFeaturesWizardPage extends WizardPage {

	private CheckboxTableViewer viewer;
	private FeatureTree featureTree;

	/**
	 * <p>Constructor for AvailableFeaturesWizardPage.</p>
	 *
	 * @param featureTree a {@link eu.etaxonomy.cdm.model.description.FeatureTree} object.
	 */
	protected AvailableFeaturesWizardPage(FeatureTree featureTree) {
		super("AvailableFeaturesWizardPage");		
		this.featureTree = featureTree;
		setTitle("Available Features");
		setDescription("Please select features you want to add to the tree. Features already in the tree do not show.");
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.NULL);
		composite.setLayout(new GridLayout());
		
		viewer = CheckboxTableViewer.newCheckList(composite, SWT.NULL);
		
		viewer.getControl().setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
		
		viewer.setContentProvider(new DefinedTermBaseContentProvider());		
		viewer.setLabelProvider(new DefinedTermBaseLabelProvider());
		
		viewer.setInput(getAvailableFeatures());
		
		setControl(composite);
	}

	/**
	 * <p>getSelectedFeatures</p>
	 *
	 * @return a {@link java.util.Set} object.
	 */
	public Set<Feature> getSelectedFeatures() {
		
		Object[] checkedElements = viewer.getCheckedElements();
		
		Set<Feature> features = new HashSet<Feature>(checkedElements.length);
		
		for(Object element : checkedElements){
			features.add((Feature) element);
		}
		
		return features;
	}
	
	/**
	 * We want to show only features that are not already in the featureTree
	 * 
	 * @return
	 */
	private List<Feature> getAvailableFeatures(){
		
		List<Feature> preferredFeatures = CdmStore.getTermManager().getPreferredFeatures();
		
		for(Feature featureAlreadyInTree : featureTree.getDistinctFeatures()){
			preferredFeatures.remove(featureAlreadyInTree);
		}
		
		return preferredFeatures;
		
	}
}
