// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.featuretree;

import org.eclipse.jface.wizard.Wizard;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IFeatureTreeService;
import eu.etaxonomy.cdm.model.description.FeatureTree;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>FeatureTreeEditorWizard class.</p>
 *
 * @author n.hoffmann
 * @created Aug 5, 2010
 * @version 1.0
 */
public class FeatureTreeEditorWizard extends Wizard {
	
	private SelectFeatureTreeWizardPage selectFeatureTreePage;
	private EditFeatureTreeWizardPage editFeatureTreePage;
	
	private FeatureTree selectedFeatureTree;

	private ConversationHolder conversation;
	
	/**
	 * <p>Constructor for FeatureTreeEditorWizard.</p>
	 */
	public FeatureTreeEditorWizard(){
		conversation = CdmStore.createConversation();
		setWindowTitle("Feature Tree Editor");
	}
	
	/**
	 * <p>addPages</p>
	 */
	public void addPages() {
		selectFeatureTreePage = new SelectFeatureTreeWizardPage("SELECT");
		addPage(selectFeatureTreePage);
		
		editFeatureTreePage = new EditFeatureTreeWizardPage("EDIT");
		addPage(editFeatureTreePage);
	}



	/** {@inheritDoc} */
	@Override
	public boolean performFinish() {
		try{
			CdmStore.getService(IFeatureTreeService.class).saveOrUpdate(selectedFeatureTree);
			conversation.commit();
		}finally{
			conversation.close();
		}
		
		return true;
	}

	/**
	 * <p>Setter for the field <code>selectedFeatureTree</code>.</p>
	 *
	 * @param selectedFeatureTree the selectedFeatureTree to set
	 */
	public void setSelectedFeatureTree(FeatureTree selectedFeatureTree) {
		this.selectedFeatureTree = selectedFeatureTree;
		editFeatureTreePage.setSelectedTree(selectedFeatureTree);
	}

	/**
	 * <p>Getter for the field <code>selectedFeatureTree</code>.</p>
	 *
	 * @return the selectedFeatureTree
	 */
	public FeatureTree getSelectedFeatureTree() {
		return selectedFeatureTree;
	}
	
}
