/**
 * 
 */
package eu.etaxonomy.taxeditor.newWizard;

import java.util.UUID;

import org.apache.commons.lang.StringUtils;

import eu.etaxonomy.cdm.api.service.IClassificationService;
import eu.etaxonomy.cdm.api.service.ITaxonNodeService;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.cdm.model.taxon.ITreeNode;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.ui.section.classification.TaxonNodeWizardPage;

/**
 * <p>NewTaxonNodeWizard class.</p>
 *
 * @author n.hoffmann
 * @created Sep 15, 2009
 * @version 1.0
 */
public class NewTaxonNodeWizard extends AbstractNewEntityWizard<ITreeNode>{

	private TaxonNodeWizardPage taxonNodePage;
	private boolean openEmptyEditor;
	private UUID generatedTaxonNodeUuid;

	@Override
	public void addPages() {
		taxonNodePage = new TaxonNodeWizardPage(formFactory, getConversationHolder(), getEntity());
		addPage(taxonNodePage);
	}
	
	@Override
	protected void saveEntity() {
		if(taxonNodePage.getTaxon() == null || StringUtils.isEmpty(taxonNodePage.getTaxon().getName().getFullTitleCache())){
			openEmptyEditor = true;
		}else{
			getConversationHolder().bind();
			ITreeNode parent = getParentTreeNode();
			Taxon taxon = taxonNodePage.getTaxon();
			TaxonNode taxonNode = parent.addChildTaxon(taxon, parent.getReference(), parent.getMicroReference(), null);
			
			
			generatedTaxonNodeUuid = CdmStore.getService(ITaxonNodeService.class).saveOrUpdate(taxonNode);
		}
	}

	@Override
	protected ITreeNode createNewEntity() {		
		if(getSelection() != null){
			Object selectedObject = getSelection().getFirstElement();
			if(selectedObject instanceof ITreeNode){
				ITreeNode treeNode = (ITreeNode) selectedObject;
				
				if(treeNode instanceof Classification){
					return CdmStore.getService(IClassificationService.class).load(treeNode.getUuid());
				}
				else if(treeNode instanceof TaxonNode){
					return CdmStore.getService(ITaxonNodeService.class).load(treeNode.getUuid());
				}
			}
		}
		
		return null;
	}
	
	/**
	 * <p>openInEditor</p>
	 *
	 * @return a boolean.
	 */
	public boolean openInEditor(){
		return taxonNodePage.openInEditor();
	}
	
	/**
	 * <p>openEmpty</p>
	 *
	 * @return a boolean.
	 */
	public boolean openEmpty(){
		return openInEditor() && openEmptyEditor;
	}
	
	/**
	 * <p>getTaxonNode</p>
	 *
	 * @return a {@link eu.etaxonomy.cdm.model.taxon.TaxonNode} object.
	 */
	public TaxonNode getTaxonNode(){
		if(generatedTaxonNodeUuid != null){
			return CdmStore.getService(ITaxonNodeService.class).load(generatedTaxonNodeUuid);			
		}
		return null;
	}
	
	public ITreeNode getParentTreeNode(){
		return taxonNodePage.getParentTreeNode();
	}
	
}