// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.parser;

import eu.etaxonomy.cdm.model.agent.TeamOrPersonBase;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.cdm.strategy.match.IMatchStrategy;
import eu.etaxonomy.cdm.strategy.match.MatchException;
import eu.etaxonomy.cdm.strategy.match.MatchMode;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;

/**
 * This class defines the MatchStrategies that will be used by the ParseHandler.
 *
 * @author n.hoffmann
 * @created Jan 22, 2010
 * @version 1.0
 */
public class MatchStrategyConfigurator {
	
	/**
	 * <p>NonViralNameMatchStrategy</p>
	 *
	 * @throws eu.etaxonomy.cdm.strategy.match.MatchException if any.
	 * @return a {@link eu.etaxonomy.cdm.strategy.match.IMatchStrategy} object.
	 */
	public static IMatchStrategy NonViralNameMatchStrategy() throws MatchException{
		return getDefaultNonViralNameMatchStrategy();// PreferencesUtil.getMatchStrategy(NonViralName.class);
	}
	
	/**
	 * <p>TeamOrPersonMatchStrategy</p>
	 *
	 * @throws eu.etaxonomy.cdm.strategy.match.MatchException if any.
	 * @return a {@link eu.etaxonomy.cdm.strategy.match.IMatchStrategy} object.
	 */
	public static IMatchStrategy TeamOrPersonMatchStrategy() throws MatchException{
		return null;// PreferencesUtil.getMatchStrategy(TeamOrPersonBase.class);
	} 
	
	/**
	 * <p>ReferenceMatchStrategy</p>
	 *
	 * @throws eu.etaxonomy.cdm.strategy.match.MatchException if any.
	 * @return a {@link eu.etaxonomy.cdm.strategy.match.IMatchStrategy} object.
	 */
	public static IMatchStrategy ReferenceMatchStrategy() throws MatchException{
		return getDefaultReferenceMatchStrategy();// PreferencesUtil.getMatchStrategy(ReferenceBase.class);
	}

	/**
	 * <p>getDefaultNonViralNameMatchStrategy</p>
	 *
	 * @throws eu.etaxonomy.cdm.strategy.match.MatchException if any.
	 * @return a {@link eu.etaxonomy.cdm.strategy.match.IMatchStrategy} object.
	 */
	public static IMatchStrategy getDefaultNonViralNameMatchStrategy() throws MatchException{
		IMatchStrategy strategy = PreferencesUtil.getDefaultMatchStrategy(NonViralName.class);
		
		strategy.setMatchMode("nomenclaturalReference", MatchMode.IGNORE);
		strategy.setMatchMode("combinationAuthorTeam", MatchMode.IGNORE);
		strategy.setMatchMode("exCombinationAuthorTeam", MatchMode.IGNORE);
		strategy.setMatchMode("basionymAuthorTeam", MatchMode.IGNORE);
		strategy.setMatchMode("exBasionymAuthorTeam", MatchMode.IGNORE);
		
		return strategy;
	}

	/**
	 * <p>getDefaultTeamOrPersonMatchStrategy</p>
	 *
	 * @return a {@link eu.etaxonomy.cdm.strategy.match.IMatchStrategy} object.
	 * @throws eu.etaxonomy.cdm.strategy.match.MatchException if any.
	 */
	public static IMatchStrategy getDefaultTeamOrPersonMatchStrategy() throws MatchException{
		IMatchStrategy strategy = PreferencesUtil.getDefaultMatchStrategy(TeamOrPersonBase.class);
		
		return strategy;
	}
	

	/**
	 * <p>getDefaultReferenceMatchStrategy</p>
	 *
	 * @return a {@link eu.etaxonomy.cdm.strategy.match.IMatchStrategy} object.
	 * @throws eu.etaxonomy.cdm.strategy.match.MatchException if any.
	 */
	public static IMatchStrategy getDefaultReferenceMatchStrategy() throws MatchException{
		IMatchStrategy strategy = PreferencesUtil.getDefaultMatchStrategy(Reference.class);
		
		strategy.setMatchMode("title", MatchMode.EQUAL);
		strategy.setMatchMode("inReference", MatchMode.IGNORE);
		
		return strategy;
	}

	/**
	 * <p>setMatchStrategy</p>
	 *
	 * @param matchStrategy a {@link eu.etaxonomy.cdm.strategy.match.IMatchStrategy} object.
	 */
	public static void setMatchStrategy(IMatchStrategy matchStrategy) {
		PreferencesUtil.setMatchStrategy(matchStrategy);
	}
	
}
