// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.preference.menu;

import java.util.List;

import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.ViewerComparator;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;

import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.taxeditor.store.TermStore;

/**
 * <p>LanguageMenuPreferences class.</p>
 *
 * @author p.ciardelli
 * @created 24.08.2009
 * @version 1.0
 */
public class LanguageMenuPreferences extends AbstractMenuPreferences<Language> {
	
	/** Constant <code>ID="eu.etaxonomy.taxeditor.preferences.lang"{trunked}</code> */
	public final static String ID = "eu.etaxonomy.taxeditor.preferences.languages";
	
	/**
	 * <p>Constructor for LanguageMenuPreferences.</p>
	 */
	public LanguageMenuPreferences() {
		super("Language Preferences", 
				"Configure language preferences.",
				false);
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.preference.AbstractMenuPreferences#createContents(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	public Control createContents(Composite parent) {
		Control control = super.createContents(parent);
		
		tableViewer.setLabelProvider(new LanguagePreferenceLabelProvider());
		tableViewer.setComparator(new ViewerComparator());
		
		return control;
	}
		
	class LanguagePreferenceLabelProvider extends LabelProvider implements ITableLabelProvider{

		/* (non-Javadoc)
		 * @see org.eclipse.jface.viewers.ITableLabelProvider#getColumnImage(java.lang.Object, int)
		 */
		public Image getColumnImage(Object element, int columnIndex) {
			return null;
		}

		/* (non-Javadoc)
		 * @see org.eclipse.jface.viewers.ITableLabelProvider#getColumnText(java.lang.Object, int)
		 */
		public String getColumnText(Object element, int columnIndex) {
			String description = ((Language)element).getDescription();
			if (description == null) {
				description = ((Language)element).getLabel() + " - Warning: no description - not shown in menus";
			}
			return description;
		}
		
		}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.preference.menu.AbstractMenuPreferences#getTermClass()
	 */
	/** {@inheritDoc} */
	@Override
	protected Class<Language> getTermClass() {
		return Language.class;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.preference.menu.AbstractMenuPreferences#getTerms()
	 */
	@Override
	protected List<Language> getTerms() {
		return TermStore.getLanguages();
	}
}
