// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.preference.menu;

import java.util.List;

import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;

import eu.etaxonomy.cdm.model.name.NameRelationshipType;
import eu.etaxonomy.taxeditor.labels.ILabelImageStrategy;
import eu.etaxonomy.taxeditor.labels.LabelImageProvider;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.TermStore;

/**
 * <p>NameRelationshipTypeMenuPreferences class.</p>
 *
 * @author n.hoffmann
 * @created 25.06.2009
 * @version 1.0
 */
public class NameRelationshipTypeMenuPreferences extends
		AbstractMenuPreferences<NameRelationshipType> {

	
	/**
	 * <p>Constructor for NameRelationshipTypeMenuPreferences.</p>
	 */
	public NameRelationshipTypeMenuPreferences() {
		super("Name relationship types", 
				"Configure name relationship types",
				false);
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.preference.AbstractMenuPreferences#createContents(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	public Control createContents(Composite parent) {
		Control container = super.createContents(parent);
		getTableViewer().setLabelProvider(new NameRelationLabelProvider());
		return container;
	}
	
	public class NameRelationLabelProvider extends DefinedTermBaseLabelProvider {

		private LabelImageProvider labelProvider;

		public NameRelationLabelProvider() {
			super();
			
			ILabelImageStrategy strategy = LabelImageProvider.getLabelStrategy(
							PreferencesUtil.getPreferredNomenclaturalCode().getNewTaxonNameInstance(null));
			this.labelProvider = new LabelImageProvider(strategy);
		}
		
		/* (non-Javadoc)
		 * @see eu.etaxonomy.taxeditor.preference.AbstractMenuPreferences.MenuPreferenceLabelProvider#getColumnImage(java.lang.Object, int)
		 */
		@Override
		public Image getColumnImage(Object element, int columnIndex) {
			// The preference page looked lame with images 
//			if (element instanceof NameRelationshipType) {
//				return labelProvider.getNameRelationImage((NameRelationshipType) element);
//			}
			return super.getColumnImage(element, columnIndex);
		}
		
		/* (non-Javadoc)
		 * @see eu.etaxonomy.taxeditor.preference.AbstractMenuPreferences.MenuPreferenceLabelProvider#getColumnText(java.lang.Object, int)
		 */
		@Override
		public String getColumnText(Object element, int columnIndex) {
			if (element instanceof NameRelationshipType) {
				return labelProvider.getNameRelationTypeLabel((NameRelationshipType) element);
			}
			return super.getColumnText(element, columnIndex);
		}
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.preference.menu.AbstractMenuPreferences#getTermClass()
	 */
	/** {@inheritDoc} */
	@Override
	protected Class<NameRelationshipType> getTermClass() {
		return NameRelationshipType.class;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.preference.menu.AbstractMenuPreferences#getTerms()
	 */
	@Override
	protected List<NameRelationshipType> getTerms() {
		return TermStore.getNameRelationshipTypes();
	}
}
