/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.preference.menu;

import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IWorkbenchPreferencePage;

import eu.etaxonomy.cdm.model.name.Rank;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.TermStore;

/**
 * Allows the user to choose which <code>Rank</code>s to display in the
 * <code>PropertySheet</code> drop-down menu for <code>TaxonNameBase</code>.
 *
 * @author p.ciardelli
 * @author n.hoffmann
 * @created 17.09.2008
 * @version 1.0
 */
public class RankMenuPreferences extends AbstractMenuPreferences<Rank> implements
		IWorkbenchPreferencePage {

	/** Constant <code>PLUGIN_ID="eu.etaxonomy.taxeditor.preferences.rank"{trunked}</code> */
	public static final String PLUGIN_ID = "eu.etaxonomy.taxeditor.preferences.ranks";

	/**
	 * <p>Constructor for RankMenuPreferences.</p>
	 */
	public RankMenuPreferences() {
		super("Rank Preferences", 
				"Choose which ranks to display in the property sheet drop-down menu.",
				false);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.preference.menu.AbstractMenuPreferences#createAdditionalContent(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	protected void createAdditionalContent(Composite container) {
		
		// TODO create option to sort ranks either alphabetically or hierarchically (asc- or descending)
		
		final Button checkbox = new Button(container, SWT.CHECK);
		checkbox.setText("Sort ranks hierarchically (default is alphabetically)");
		
		checkbox.setSelection(PreferencesUtil.getSortRanksHierarchichally());
		
		checkbox.addSelectionListener(new SelectionAdapter() {
			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.SelectionAdapter#widgetSelected(org.eclipse.swt.events.SelectionEvent)
			 */
			@Override
			public void widgetSelected(SelectionEvent e) {
				PreferencesUtil.setSortRanksHierarchichally(checkbox.getSelection());
				refresh(TermStore.getRanks());
			}
		});
		
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.preference.menu.AbstractMenuPreferences#getTermClass()
	 */
	/** {@inheritDoc} */
	@Override
	protected Class<Rank> getTermClass() {
		return Rank.class;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.preference.menu.AbstractMenuPreferences#getTerms()
	 */
	@Override
	protected List<Rank> getTerms() {
		return TermStore.getRanks();
	}

}
