// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.dialogs.filteredSelection;

import java.util.UUID;

import org.eclipse.swt.widgets.Shell;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.service.IAgentService;
import eu.etaxonomy.cdm.model.agent.Team;
import eu.etaxonomy.taxeditor.newWizard.AbstractNewEntityWizard;
import eu.etaxonomy.taxeditor.newWizard.NewTeamWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * <p>FilteredTeamSelectionDialog class.</p>
 *
 * @author n.hoffmann
 * @created Sep 24, 2009
 * @version 1.0
 */
public class TeamSelectionDialog extends
		AbstractFilteredCdmResourceSelectionDialog<Team> {
	
	/**
	 * <p>select</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param team a {@link eu.etaxonomy.cdm.model.agent.Team} object.
	 * @return a {@link eu.etaxonomy.cdm.model.agent.Team} object.
	 */
	public static Team select(Shell shell, ConversationHolder conversation, Team team){
		TeamSelectionDialog dialog = new TeamSelectionDialog(shell, conversation,
				"Choose Team", false, TeamSelectionDialog.class.getCanonicalName(), team);
		return getSelectionFromDialog(dialog);
	}
	
	/**
	 * <p>Constructor for FilteredTeamSelectionDialog.</p>
	 *
	 * @param shell a {@link org.eclipse.swt.widgets.Shell} object.
	 * @param title a {@link java.lang.String} object.
	 * @param multi a boolean.
	 * @param settings a {@link java.lang.String} object.
	 * @param cdmObject a {@link eu.etaxonomy.cdm.model.agent.Team} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 */
	protected TeamSelectionDialog(Shell shell, ConversationHolder conversation,
			String title, boolean multi, String settings,
			Team cdmObject) {
		super(shell, conversation, title, multi, settings, cdmObject);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.dialogs.filteredSelection.AbstractFilteredCdmResourceSelectionDialog#initModel()
	 */
	/** {@inheritDoc} */
	@Override
	protected void initModel() {
		model = CdmStore.getService(IAgentService.class).getTeamUuidAndTitleCache();
	}

	/** {@inheritDoc} */
	@Override
	protected AbstractNewEntityWizard getNewEntityWizard(String parameter) {
		return new NewTeamWizard();
	}

	/** {@inheritDoc} */
	@Override
	protected String getNewWizardLinkText() {
		return "Click link to create a new <A>Team</A>.";
	}

	/** {@inheritDoc} */
	@Override
	protected Team getPersistentObject(UUID uuid) {
		return (Team) CdmStore.getService(IAgentService.class).load(uuid);
	}
}
