// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.forms;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.Button;

import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.common.LanguageString;
import eu.etaxonomy.cdm.model.common.MultilanguageTextHelper;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.TermComboType;
import eu.etaxonomy.taxeditor.ui.term.EmptyComboElement;
import eu.etaxonomy.taxeditor.ui.translation.TranslationWizard;

/**
 * <p>
 * MultilanguageTextElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Sep 29, 2010
 * @version 1.0
 */
public class MultilanguageTextElement extends AbstractCdmFormElement implements
		SelectionListener {

	private class OpenTranslationWizard extends SelectionAdapter {
		private final Map<Language, LanguageString> multilanguageText;

		public OpenTranslationWizard(
				Map<Language, LanguageString> multilanguageText) {
			super();
			this.multilanguageText = multilanguageText;
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * org.eclipse.swt.events.SelectionAdapter#widgetSelected(org.eclipse
		 * .swt.events.SelectionEvent)
		 */
		@Override
		public void widgetSelected(SelectionEvent e) {
			TranslationWizard wizard = new TranslationWizard(multilanguageText);
			WizardDialog dialog = new WizardDialog(getLayoutComposite()
					.getShell(), wizard);

			if (dialog.open() == IStatus.OK) {
				combo_language.setTerms(getLanguages());
				updateControls();
			}

		}
	}

	private EmptyComboElement<Language> combo_language;

	protected LanguageStringWithLabelElement element_languageString;

	private Button button;

	private Map<Language, LanguageString> multilanguageText;

	/**
	 * <p>
	 * Constructor for MultilanguageTextElement.
	 * </p>
	 * 
	 * @param formFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement}
	 *            object.
	 * @param labelString
	 *            a {@link java.lang.String} object.
	 * @param multilanguageText
	 *            a {@link java.util.Map} object.
	 * @param textHeight
	 *            a {@link java.lang.Integer} object.
	 * @param style
	 *            a int.
	 */
	public MultilanguageTextElement(CdmFormFactory formFactory,
			ICdmFormElement formElement, String labelString,
			Map<Language, LanguageString> multilanguageText,
			Integer textHeight, int style) {
		super(formFactory, formElement);

		formFactory.addPropertyChangeListener(this);

		element_languageString = formFactory
				.createLanguageStringWithLabelElement(formElement, labelString,
						null, textHeight, style);

		if (PreferencesUtil.isMultilanguageTextEditingCapability()) {
			combo_language = (EmptyComboElement<Language>) formFactory
					.createTermComboElement(TermComboType.EMPTY, formElement,
							"", null, style);
			combo_language.addSelectionListener(this);
			addControl(formFactory.createLabel(getLayoutComposite(), ""));
			button = formFactory.createButton(getLayoutComposite(),
					"Open In Translation Editor", SWT.PUSH);
			addControl(button);
			button.setLayoutData(CdmFormFactory.RIGHT());
			button.addSelectionListener(new OpenTranslationWizard(
					multilanguageText));
		}
		setMultilanguageText(multilanguageText);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see eu.etaxonomy.taxeditor.forms.ISelectable#setSelected(boolean)
	 */
	/** {@inheritDoc} */
	@Override
	public void setSelected(boolean selected) {
		//
	}

	private List<Language> getLanguages() {

		ArrayList<Language> languageList = new ArrayList<Language>(
				getMultilanguageText().keySet());

		// TODO sort

		return languageList;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt
	 * .events.SelectionEvent)
	 */
	/** {@inheritDoc} */
	@Override
	public void widgetSelected(SelectionEvent e) {
		Language selectedLanguage = combo_language.getSelection();
		if (selectedLanguage != null) {
			LanguageString selectedLanguageString = getMultilanguageText().get(
					selectedLanguage);

			element_languageString.setLanguageString(selectedLanguageString);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse
	 * .swt.events.SelectionEvent)
	 */
	/** {@inheritDoc} */
	@Override
	public void widgetDefaultSelected(SelectionEvent e) {
	}

	/**
	 * <p>
	 * Setter for the field <code>multilanguageText</code>.
	 * </p>
	 * 
	 * @param multilanguageText
	 *            the multilanguageText to set
	 */
	public void setMultilanguageText(
			Map<Language, LanguageString> multilanguageText) {
		this.multilanguageText = multilanguageText;

		if (multilanguageText != null) {
			if (multilanguageText.isEmpty()) {
				multilanguageText.put(
						CdmStore.getDefaultLanguage(),
						LanguageString.NewInstance("",
								CdmStore.getDefaultLanguage()));
			}
			if (PreferencesUtil.isMultilanguageTextEditingCapability()) {
				combo_language.setTerms(getLanguages());
			}
			updateControls();
		}
	}

	/**
	 * 
	 */
	private void updateControls() {
		LanguageString preferredLanguageString = MultilanguageTextHelper
				.getPreferredLanguageString(getMultilanguageText(),
						Arrays.asList(new Language[] { CdmStore
								.getDefaultLanguage() }));

		element_languageString.setLanguageString(preferredLanguageString);
		if (PreferencesUtil.isMultilanguageTextEditingCapability()) {
			combo_language.setSelection(preferredLanguageString.getLanguage());
		}
	}

	/**
	 * <p>
	 * Getter for the field <code>multilanguageText</code>.
	 * </p>
	 * 
	 * @return the multilanguageText
	 */
	public Map<Language, LanguageString> getMultilanguageText() {
		return multilanguageText;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.forms.AbstractCdmFormElement#propertyChange(org
	 * .eclipse.jface.util.PropertyChangeEvent)
	 */
	/** {@inheritDoc} */
	@Override
	public void propertyChange(PropertyChangeEvent event) {
		if (event == null) {
			return;
		}
		Object eventSource = event.getSource();
		if (eventSource == element_languageString) {
			LanguageString languageString = ((LanguageStringWithLabelElement) eventSource)
					.getLanguageString();
			multilanguageText.put(languageString.getLanguage(), languageString);
			firePropertyChangeEvent(new CdmPropertyChangeEvent(this, event));
		}
	}
}
