/**
 * 
 */
package eu.etaxonomy.taxeditor.ui.forms;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.common.CdmUtils;

/**
 * <p>TextActionElement class.</p>
 *
 * @author nho
 * @version $Id: $
 */
public class TextActionElement extends AbstractCdmFormElement implements ModifyListener{

	private Label label;
	private Text text;
	private Button button;
	private Composite box;

	/**
	 * <p>Constructor for TextActionElement.</p>
	 *
	 * @param style a int.
	 * @param toolkit a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param labelString a {@link java.lang.String} object.
	 * @param buttonLabel a {@link java.lang.String} object.
	 * @param initialText a {@link java.lang.String} object.
	 */
	protected TextActionElement(CdmFormFactory toolkit, ICdmFormElement parentElement, String labelString, String buttonLabel, String initialText, int style) {
		super(toolkit, parentElement);
		
		label = toolkit.createLabel(getLayoutComposite(), labelString, SWT.WRAP);
		addControl(label);
		
		box = formFactory.createComposite(getLayoutComposite());
		box.setLayout(CdmFormFactory.LAYOUT(2, false));
		box.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY());
		addControl(box);
		
		text = toolkit.createText(box, "", style);
		addControl(text);
		text.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY());
		
		setText(CdmUtils.Nz(initialText));
		
		button = toolkit.createButton(box, buttonLabel, SWT.PUSH);
		addControl(button);
	}

	/**
	 * <p>Setter for the field <code>text</code>.</p>
	 *
	 * @param string a {@link java.lang.String} object.
	 */
	public void setText(String string) {
		text.setText(CdmUtils.Nz(string));
	}

	/**
	 * <p>Getter for the field <code>text</code>.</p>
	 *
	 * @return the text
	 */
	public String getText() {
		return text.getText();
	}

	/**
	 * <p>addSelectionListener</p>
	 *
	 * @param listener a {@link org.eclipse.swt.events.SelectionListener} object.
	 */
	public void addSelectionListener(SelectionListener listener){
		button.addSelectionListener(listener);
	}

	/**
	 * <p>removeSelectionListener</p>
	 *
	 * @param listener a {@link org.eclipse.swt.events.SelectionListener} object.
	 */
	public void removeSelectionListener(SelectionListener listener){
		button.removeSelectionListener(listener);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.ModifyListener#modifyText(org.eclipse.swt.events.ModifyEvent)
	 */
	/** {@inheritDoc} */
	public void modifyText(ModifyEvent e) {
		propertyChange(null);
	}

	/** {@inheritDoc} */
	public void setSelected(boolean selected) {
		label.setBackground(getColor(selected));
	}
	
	/**
	 * <p>addModifyListener</p>
	 *
	 * @param listener a {@link org.eclipse.swt.events.ModifyListener} object.
	 */
	public void addModifyListener(ModifyListener listener){
		text.addModifyListener(listener);
	}
	
	/**
	 * <p>removeModifyListener</p>
	 *
	 * @param listener a {@link org.eclipse.swt.events.ModifyListener} object.
	 */
	public void removeModifyListener(ModifyListener listener){
		text.removeModifyListener(listener);
	}
	
	/** {@inheritDoc} */
	@Override
	public void setBackground(Color color) {
		label.setBackground(color);
	}
}
