// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.openurl;

import java.net.URI;
import java.util.List;

import org.eclipse.jface.wizard.Wizard;
import org.eclipse.swt.widgets.Display;

import eu.etaxonomy.cdm.ext.openurl.MobotOpenUrlQuery;
import eu.etaxonomy.cdm.ext.openurl.MobotOpenUrlServiceWrapper;
import eu.etaxonomy.cdm.ext.openurl.MobotOpenUrlServiceWrapper.ReferenceType;
import eu.etaxonomy.cdm.ext.openurl.OpenUrlReference;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;

/**
 * @author n.hoffmann
 * @created Jan 31, 2011
 * @version 1.0
 */
public class OpenUrlSelectorWizard extends Wizard {
	
	private MobotOpenUrlServiceWrapper openUrlServiceWrapper;

	private MobotOpenUrlQuery query;
	
	private OpenUrlReference openUrlReference;
	
	private CdmFormFactory formFactory;

	private URI openUrlReferenceImageUri;
	
	private Reference reference;
	
	private String referenceDetail;
	
	
	
	/**
	 * @param openUrlSelectorElement 
	 * @param reference
	 */
	public OpenUrlSelectorWizard(Reference reference, String referenceDetail) {
		if(reference == null){
			throw new IllegalArgumentException("Reference may not be empty");
		}
		
		this.reference = reference;
		this.referenceDetail = referenceDetail;
		
		setWindowTitle("Mobot Open Url");
		setNeedsProgressMonitor(true);
		
		formFactory = new CdmFormFactory(Display.getDefault());
		
		openUrlServiceWrapper = new MobotOpenUrlServiceWrapper();
		openUrlServiceWrapper.setBaseUrl(PreferencesUtil.getPreferenceStore().getString(IPreferenceKeys.OPENURL_ACCESS_POINT));
		
		query  = new MobotOpenUrlQuery();
		
		query.refType = ReferenceType.getReferenceType(reference);
		if(reference.getAuthorTeam() != null){
			query.authorName = reference.getAuthorTeam().getTitleCache();
		}
		query.abbreviation = reference.getTitle();
		if(reference.getInReference() != null){
			query.journalTitle = reference.getInReference().getTitle();
		}
		query.ISBN = reference.getIsbn();
		query.ISSN = reference.getIssn();
		if(reference.getDatePublished() != null){
			query.publicationDate = reference.getDatePublished().toString();
		}
		query.publicationPlace = reference.getPlacePublished();
		query.publisherName = reference.getPublisher();
		query.volume = reference.getVolume();
		
		query.startPage = referenceDetail;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#addPages()
	 */
	@Override
	public void addPages() {
		
		addPage(new OpenUrlResultPage());
		addPage(new OpenUrlReferencePage());
		
		super.addPages();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	@Override
	public boolean performFinish() {
		return true;
	}

	/**
	 * @param openUrlReference the openUrlReference to set
	 */
	public void setOpenUrlReference(OpenUrlReference openUrlReference) {
		this.openUrlReference = openUrlReference;
		this.openUrlReferenceImageUri = openUrlReference.getJpegImage(PreferencesUtil.getPreferenceStore().getInt(IPreferenceKeys.OPENURL_IMAGE_MAX_WIDTH)
				, PreferencesUtil.getPreferenceStore().getInt(IPreferenceKeys.OPENURL_IMAGE_MAX_HEIGHT));
	}

	/**
	 * @return the openUrlReference
	 */
	public OpenUrlReference getOpenUrlReference() {
		return openUrlReference;
	}

	/**
	 * @return
	 */
	public List<OpenUrlReference> getResult() {
		return openUrlServiceWrapper.doResolve(query);
	}

	/**
	 * @return the formFactory
	 */
	public CdmFormFactory getFormFactory() {
		return formFactory;
	}

	/**
	 * @return the openUrlServiceWrapper
	 */
	public MobotOpenUrlServiceWrapper getOpenUrlServiceWrapper() {
		return openUrlServiceWrapper;
	}

	/**
	 * @return
	 */
	public URI getOpenUrlReferenceImageUri() {
		return openUrlReferenceImageUri;
	}

	public Reference getReference() {
		return reference;
	}

	public String getReferenceDetail() {
		return referenceDetail;
	}
}
