// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.agent;

import java.util.Arrays;
import java.util.Collection;

import org.eclipse.swt.SWT;

import eu.etaxonomy.cdm.model.agent.Person;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.forms.ToggleableTextElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractIdentifiableEntityDetailElement;

/**
 * <p>
 * PersonDetailElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Mar 8, 2010
 * @version 1.0
 */
public class PersonDetailElement extends AbstractIdentifiableEntityDetailElement<Person> {

	private TextWithLabelElement text_nomenclaturalTitle;
	private TextWithLabelElement text_firstname;
	private TextWithLabelElement text_lastname;
	private TextWithLabelElement text_prefix;
	private TextWithLabelElement text_suffix;

	private Collection<Object> excludeFromIrrelevantToggleableObjects;

	/**
	 * <p>
	 * Constructor for PersonDetailElement.
	 * </p>
	 * 
	 * @param cdmFormFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement}
	 *            object.
	 * @param style
	 *            a int.
	 */
	public PersonDetailElement(CdmFormFactory cdmFormFactory,
			ICdmFormElement formElement, int style) {
		super(cdmFormFactory, formElement);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement, Person entity,
			int style) {
		toggleable_cache = formFactory.createToggleableTextField(formElement,
				"Title Cache", entity.getTitleCache(),
				entity.isProtectedTitleCache(), SWT.NULL);

		text_nomenclaturalTitle = formFactory.createTextWithLabelElement(
				formElement, "Abbrev. Title", entity.getNomenclaturalTitle(),
				SWT.NULL);

		text_firstname = formFactory.createTextWithLabelElement(formElement,
				"Firstname", entity.getFirstname(), SWT.NULL);
		text_lastname = formFactory.createTextWithLabelElement(formElement,
				"Lastname", entity.getLastname(), SWT.NULL);

		text_prefix = formFactory.createTextWithLabelElement(formElement,
				"Prefix", entity.getPrefix(), SWT.NULL);
		text_suffix = formFactory.createTextWithLabelElement(formElement,
				"Suffix", entity.getSuffix(), SWT.NULL);
	}

	/** {@inheritDoc} */
	@Override
	protected void updateContent() {
		super.updateContent();

		excludeFromIrrelevantToggleableObjects = Arrays.asList(new Object[] {
				toggleable_cache, text_nomenclaturalTitle });

		toggleable_cache.setEnabled(getEntity().isProtectedTitleCache());
		setIrrelevant(toggleable_cache.getState(),
				excludeFromIrrelevantToggleableObjects);
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == toggleable_cache) {	
			handleToggleableCacheField();			
		} else if (eventSource == text_nomenclaturalTitle) {
			getEntity()
					.setNomenclaturalTitle(text_nomenclaturalTitle.getText());
		} else if (eventSource == text_firstname) {
			getEntity().setFirstname(text_firstname.getText());
		} else if (eventSource == text_lastname) {
			getEntity().setLastname(text_lastname.getText());
		} else if (eventSource == text_prefix) {
			getEntity().setPrefix(text_prefix.getText());
		} else if (eventSource == text_suffix) {
			getEntity().setSuffix(text_suffix.getText());
		}

		if (eventSource != toggleable_cache) {
			toggleable_cache.setText(getEntity().getTitleCache());
		}

		firePropertyChangeEvent(new CdmPropertyChangeEvent(this, null));
	}
}
