// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.agent;

import java.util.Arrays;

import org.eclipse.ui.forms.widgets.Section;

import eu.etaxonomy.cdm.model.agent.Team;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.EntityDetailType;
import eu.etaxonomy.taxeditor.ui.forms.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.ToggleableTextElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractIdentifiableEntityDetailElement;

/**
 * <p>
 * TeamDetailElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Apr 26, 2010
 * @version 1.0
 */
public class TeamDetailElement extends AbstractIdentifiableEntityDetailElement<Team> {

	private ToggleableTextElement toggleable_nomenclaturalTitleCache;

	private TeamMemberSection section_teamMembers;

	/**
	 * <p>
	 * Constructor for TeamDetailElement.
	 * </p>
	 * 
	 * @param cdmFormFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement}
	 *            object.
	 * @param style
	 *            a int.
	 */
	public TeamDetailElement(CdmFormFactory cdmFormFactory,
			ICdmFormElement formElement, int style) {
		super(cdmFormFactory, formElement);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement, Team entity,
			int style) {

		toggleable_cache = formFactory.createToggleableTextField(formElement,
				"Title Cache", entity.getTitleCache(),
				entity.isProtectedTitleCache(), style);
		toggleable_nomenclaturalTitleCache = formFactory
				.createToggleableTextField(formElement, "Abbrev. Title",
						entity.getNomenclaturalTitle(),
						entity.isProtectedNomenclaturalTitleCache(), style);
		section_teamMembers = (TeamMemberSection) formFactory
				.createEntityDetailSection(EntityDetailType.TEAMMEMBER,
						getConversationHolder(), formElement, Section.EXPANDED);
		section_teamMembers.setLayoutData(CdmFormFactory
				.FILL_HORIZONTALLY(2, 1));
	}

	/** {@inheritDoc} */
	@Override
	protected void updateContent() {
		super.updateContent();

		toggleable_cache.setEnabled(getEntity().isProtectedTitleCache());
		toggleable_nomenclaturalTitleCache.setEnabled(getEntity()
				.isProtectedNomenclaturalTitleCache());
		setIrrelevant(
				toggleable_cache.getState(),
				Arrays.asList(new Object[] { toggleable_cache,
						toggleable_nomenclaturalTitleCache }));

		section_teamMembers.setEntity(getEntity());

	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == toggleable_cache) {
			handleToggleableCacheField();
		} else if (eventSource == toggleable_nomenclaturalTitleCache) {
			getEntity().setNomenclaturalTitle(
					toggleable_nomenclaturalTitleCache.getText(),
					toggleable_nomenclaturalTitleCache.getState());
			setIrrelevant(
					toggleable_nomenclaturalTitleCache.getState(),
					Arrays.asList(new Object[] { toggleable_nomenclaturalTitleCache }));
		} else if (eventSource == section_teamMembers) {
			toggleable_cache.setText(getEntity().getTitleCache());
			toggleable_nomenclaturalTitleCache.setText(getEntity()
					.getNomenclaturalTitle());
		}

		firePropertyChangeEvent(new CdmPropertyChangeEvent(this, null));
	}
}
