// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.agent;

import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.model.agent.Person;
import eu.etaxonomy.cdm.model.agent.Team;
import eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;
import eu.etaxonomy.taxeditor.ui.selection.PersonSelectionElement;

/**
 * <p>
 * TeamMemberElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Apr 30, 2010
 * @version 1.0
 */
public class TeamMemberElement extends AbstractEntityCollectionElement<Person> {

	private PersonSelectionElement selection_person;

	/**
	 * <p>
	 * Constructor for TeamMemberElement.
	 * </p>
	 * 
	 * @param cdmFormFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param section
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection}
	 *            object.
	 * @param entity
	 *            a {@link eu.etaxonomy.cdm.model.agent.Person} object.
	 * @param removeListener
	 *            a {@link org.eclipse.swt.events.SelectionListener} object.
	 * @param style
	 *            a int.
	 */
	public TeamMemberElement(CdmFormFactory cdmFormFactory,
			AbstractFormSection section, Person entity,
			SelectionListener removeListener, int style) {
		super(cdmFormFactory, section, entity, removeListener, null, style);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.section.AbstractEntityCollectionElement#createControls
	 * (eu.etaxonomy.taxeditor.forms.ICdmFormElement, int)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControls(ICdmFormElement element, int style) {
		selection_person = (PersonSelectionElement) formFactory
				.createSelectionElement(SelectionType.PERSON,
						getConversationHolder(), this, "Person", null,
						PersonSelectionElement.DEFAULT, style);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.section.AbstractEntityCollectionElement#setEntity
	 * (eu.etaxonomy.cdm.model.common.VersionableEntity)
	 */
	/** {@inheritDoc} */
	@Override
	public void setEntity(Person entity) {
		this.entity = entity;
		selection_person.setEntity(entity);
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == selection_person) {
			if (getParentElement() instanceof TeamMemberSection) {
				TeamMemberSection teamMemberSection = (TeamMemberSection) getParentElement();
				Team team = teamMemberSection.getEntity();

				int index = team.getTeamMembers().indexOf(getEntity());

				team.removeTeamMember(getEntity());
				team.addTeamMember(selection_person.getEntity(), index);
				firePropertyChangeEvent(new CdmPropertyChangeEvent(
						teamMemberSection, eventSource));
			}
			entity = selection_person.getEntity();

		}
	}
}
