// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.agent;

import java.util.Collection;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.agent.Person;
import eu.etaxonomy.cdm.model.agent.Team;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;

/**
 * <p>TeamMemberSection class.</p>
 *
 * @author n.hoffmann
 * @created Apr 30, 2010
 * @version 1.0
 */
public class TeamMemberSection extends AbstractEntityCollectionSection<Team, Person> {

	/**
	 * <p>Constructor for TeamMemberSection.</p>
	 *
	 * @param cdmFormFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param style a int.
	 */
	public TeamMemberSection(CdmFormFactory cdmFormFactory, ConversationHolder conversation, ICdmFormElement parentElement, int style) {
		super(cdmFormFactory, conversation, parentElement, null, style);
	}
	
	/** {@inheritDoc} */
	@Override
	public String getTitleString() {
		return "Team Members";
	}

	/** {@inheritDoc} */
	@Override
	public void addElement(Person element) {
		getEntity().addTeamMember(element);
	}

	/** {@inheritDoc} */
	@Override
	public Person createNewElement() {
		return Person.NewTitledInstance("");
	}

	/** {@inheritDoc} */
	@Override
	public Collection<Person> getCollection(Team entity) {
		return getEntity().getTeamMembers();
	}

	/** {@inheritDoc} */
	@Override
	public String getEmptyString() {
		return "No persons yet.";
	}

	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Add a membmer to this team";
	}

	/** {@inheritDoc} */
	@Override
	public void removeElement(Person element) {
		getEntity().removeTeamMember(element);
	}
	
	
}
