// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.description;

import java.util.Collection;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.cdm.model.occurrence.DerivedUnit;
import eu.etaxonomy.cdm.model.occurrence.SpecimenOrObservationBase;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;

/**
 * <p>DescribedSpecimenSection class.</p>
 *
 * @author n.hoffmann
 * @created Sep 16, 2010
 * @version 1.0
 */
public class DescribedSpecimenSection extends AbstractEntityCollectionSection<TaxonDescription, SpecimenOrObservationBase> {

	/**
	 * <p>Constructor for DescribedSpecimenSection.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param style a int.
	 */
	public DescribedSpecimenSection(CdmFormFactory formFactory,
			ConversationHolder conversation, ICdmFormElement parentElement,
			int style) {
		super(formFactory, conversation, parentElement, "Described Specimen", style);
	}
	
	/** {@inheritDoc} */
	@Override
	public Collection<SpecimenOrObservationBase> getCollection(
			TaxonDescription entity) {
		return entity.getDescribedSpecimenOrObservations();
	}

	/** {@inheritDoc} */
	@Override
	public SpecimenOrObservationBase createNewElement() {
		return DerivedUnit.NewInstance();
	}

	/** {@inheritDoc} */
	@Override
	public void addElement(SpecimenOrObservationBase element) {
		getEntity().addDescribedSpecimenOrObservation(element);
	}

	/** {@inheritDoc} */
	@Override
	public void removeElement(SpecimenOrObservationBase element) {
		getEntity().removeDescribedSpecimenOrObservation(element);
	}

	/** {@inheritDoc} */
	@Override
	public String getEmptyString() {
		return "No described specimen yet.";
	}

	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Add a described specimen.";
	}
}
