// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.description;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.ToolBarManager;
import org.eclipse.jface.viewers.ISelectionProvider;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Control;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.TextData;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.DetailType;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailSection;
import eu.etaxonomy.taxeditor.ui.section.description.operation.ChangeDescriptionElementType;

/**
 * <p>DescriptionElementDetailSection class.</p>
 *
 * @author n.hoffmann
 * @created Mar 5, 2010
 * @version 1.0
 */
public class DescriptionElementDetailSection extends
		AbstractCdmDetailSection<DescriptionElementBase> {
	
	/**
	 * <p>Constructor for DescriptionElementDetailSection.</p>
	 *
	 * @param cdmFormFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param selectionProvider a {@link org.eclipse.jface.viewers.ISelectionProvider} object.
	 * @param style a int.
	 */
	public DescriptionElementDetailSection(CdmFormFactory cdmFormFactory, ConversationHolder conversation,
			ICdmFormElement parentElement, ISelectionProvider selectionProvider, int style) {
		super(cdmFormFactory, conversation, parentElement, selectionProvider, style);
	}
	
	
	protected Control createToolbar() {
		if(! hasSpecificElement()){
			return null;
		}
		
		ToolBarManager toolBarManager = new ToolBarManager(SWT.FLAT);
		
		final String destinationString = (getEntity() instanceof TextData) ? "the specific element" : "free text";
		
		final String label = "Change to " + destinationString; 
		
		Action addAction = new Action("Change Type", Action.AS_PUSH_BUTTON) {
			/* (non-Javadoc)
			 * @see org.eclipse.jface.action.Action#run()
			 */
			@Override
			public void run() {
				boolean confirmed = StoreUtil.confirmDialog("Confirmation", "Do you really want to change to "
						+ destinationString + "? Current data will be lost.");
				if (confirmed) {
					// FIXME
					ChangeDescriptionElementType operation = new ChangeDescriptionElementType(label, 
							getEntity(), StoreUtil.getDetailsView(), StoreUtil.getUndoContext());
					StoreUtil.executeOperation(operation);
				}
			}
		};
		// TODO enable this once a proper icon has been found 
//		addAction.setImageDescriptor(new ImageDescriptor() {
//			
//			@Override
//			public ImageData getImageData() {
//				return ImageResources.getImage(ImageResources.ADD_ICON).getImageData();
//			}
//		});
		addAction.setToolTipText(label);
		
		toolBarManager.add(addAction);
		
		ICdmFormElement parentElement = this.getParentElement();
		
		
		return toolBarManager.createControl(this);
	}
	
	/** {@inheritDoc} */
	@Override
	public String getHeading() {
		return "Description Element";
	}

	/** {@inheritDoc} */
	@Override
	protected DetailType getDetailType() {
		return DetailType.DESCRIPTIONELEMENT;
	}
	
	/** {@inheritDoc} */
	@Override
	protected void setSectionTitle() {
		this.setText(getHeading() + ": " + getEntity().getFeature().getLabel(CdmStore.getDefaultLanguage()));
		setTextClient(createToolbar());
	}
	
	private boolean hasSpecificElement(){
		return  getEntity().getFeature().isSupportsCategoricalData() 
				|| getEntity().getFeature().isSupportsCommonTaxonName()
				|| getEntity().getFeature().isSupportsDistribution()
				|| getEntity().getFeature().isSupportsIndividualAssociation()
				|| getEntity().getFeature().isSupportsQuantitativeData()
				|| getEntity().getFeature().isSupportsTaxonInteraction();
	}
}
