// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.description;

import java.util.Collection;

import org.apache.log4j.Logger;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.description.IModifiable;
import eu.etaxonomy.cdm.model.description.Modifier;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;

/**
 * <p>ModifierSection class.</p>
 *
 * @author n.hoffmann
 * @created Sep 15, 2010
 * @version 1.0
 */
public class ModifierSection extends AbstractEntityCollectionSection<IModifiable, Modifier> {


	private static final Logger logger = Logger
			.getLogger(ModifierSection.class);

	/**
	 * <p>Constructor for ModifierSection.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param style a int.
	 */
	public ModifierSection(CdmFormFactory formFactory,
			ConversationHolder conversation, ICdmFormElement parentElement,
			int style) {
		super(formFactory, conversation, parentElement, "Modifiers", style);
	}
	
	/** {@inheritDoc} */
	@Override
	public Collection<Modifier> getCollection(IModifiable entity) {
		return entity.getModifiers();
	}

	/** {@inheritDoc} */
	@Override
	public Modifier createNewElement() {
		return Modifier.NewInstance();
	}

	/** {@inheritDoc} */
	@Override
	public void addElement(Modifier element) {
		getEntity().addModifier(element);
	}

	/** {@inheritDoc} */
	@Override
	public void removeElement(Modifier element) {
		getEntity().removeModifier(element);
	}

	/** {@inheritDoc} */
	@Override
	public String getEmptyString() {
		return "No modifiers yet.";
	}

	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Add a modifier.";
	}
}
