// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.description.detail;

import org.apache.log4j.Logger;
import org.eclipse.swt.SWT;

import eu.etaxonomy.cdm.model.description.CommonTaxonName;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.TermComboType;
import eu.etaxonomy.taxeditor.ui.selection.NamedAreaSelectionElement;
import eu.etaxonomy.taxeditor.ui.term.LanguageComboElement;

/**
 * <p>CommonNameDetailElement class.</p>
 *
 * @author n.hoffmann
 * @created Jun 10, 2010
 * @version 1.0
 */
public class CommonNameDetailElement extends AbstractDetailedDescriptionDetailElement<CommonTaxonName> {

	private static final Logger logger = Logger
			.getLogger(CommonNameDetailElement.class);
	
	private LanguageComboElement combo_language;
	private NamedAreaSelectionElement selection_namedArea;
	private TextWithLabelElement commonName;

	
	/**
	 * <p>Constructor for CommonNameDetailElement.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param formElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param entity a {@link eu.etaxonomy.cdm.model.description.CommonTaxonName} object.
	 * @param style a int.
	 */
	public CommonNameDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement, CommonTaxonName entity, int style) {
		super(formFactory, formElement, entity, style);
	}
	
	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
			CommonTaxonName entity, int style) {
		combo_language = (LanguageComboElement) formFactory.createTermComboElement(TermComboType.LANGUAGE, this, "Language", entity.getLanguage(), style);

		selection_namedArea = formFactory.createNamedAreaSelectionElement(this, getConversationHolder(), "Area", entity.getArea(), style);
		
		commonName = formFactory.createTextWithLabelElement(this, "Common Name", entity.getName(), SWT.WRAP);
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if(eventSource == combo_language){
			getEntity().setLanguage(combo_language.getSelection());
		}else if(eventSource == selection_namedArea){
			getEntity().setArea(selection_namedArea.getEntity());
		}else if(eventSource == commonName){
			getEntity().setName(commonName.getText());
		}
	}

}
