// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.description.detail;

import java.util.Map;

import org.apache.log4j.Logger;

import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.common.LanguageString;
import eu.etaxonomy.cdm.model.description.IndividualsAssociation;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.selection.DerivedUnitBaseSelectionElement;

/**
 * <p>
 * IndividualsAssociationDetailElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Jun 10, 2010
 * @version 1.0
 */
public class IndividualsAssociationDetailElement extends
		AbstractDetailedDescriptionDetailElement<IndividualsAssociation> {

	private static final Logger logger = Logger
			.getLogger(IndividualsAssociationDetailElement.class);
	private TextWithLabelElement text_description;
	private DerivedUnitBaseSelectionElement selection_derivedUnit;

	/**
	 * <p>
	 * Constructor for IndividualsAssociationDetailElement.
	 * </p>
	 * 
	 * @param formFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement}
	 *            object.
	 * @param entity
	 *            a
	 *            {@link eu.etaxonomy.cdm.model.description.IndividualsAssociation}
	 *            object.
	 * @param style
	 *            a int.
	 */
	public IndividualsAssociationDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement, IndividualsAssociation entity,
			int style) {
		super(formFactory, formElement, entity, style);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
			IndividualsAssociation entity, int style) {
		selection_derivedUnit = (DerivedUnitBaseSelectionElement) formFactory
				.createSelectionElement(SelectionType.DERIVED_UNIT,
						getConversationHolder(), formElement, "Unit",
						entity.getAssociatedSpecimenOrObservation(),
						DerivedUnitBaseSelectionElement.DEFAULT, style);

		text_description = formFactory.createMultilineTextWithLabel(
				formElement, "Description", 200, style);
		Map<Language, LanguageString> descriptions = entity.getDescription();

		if (descriptions.get(CdmStore.getDefaultLanguage()) != null) {
			text_description.setText(descriptions.get(
					CdmStore.getDefaultLanguage()).getText());
		}
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == selection_derivedUnit) {
			getEntity().setAssociatedSpecimenOrObservation(
					selection_derivedUnit.getEntity());
		} else if (eventSource == text_description) {
			getEntity().addDescription(text_description.getText(),
					CdmStore.getDefaultLanguage());
		}

	}
}
