/**
 * 
 */
package eu.etaxonomy.taxeditor.ui.section.key;

import eu.etaxonomy.cdm.model.description.PolytomousKeyNode;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.KeyStatementElement;
import eu.etaxonomy.taxeditor.ui.forms.NumberWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.FeatureSelectionElement;
import eu.etaxonomy.taxeditor.ui.selection.PolytomousKeyNodeSelectionElement;
import eu.etaxonomy.taxeditor.ui.selection.PolytomousKeySelectionElement;
import eu.etaxonomy.taxeditor.ui.selection.TaxonSelectionElement;

/**
 * @author n.hoffmann
 * 
 */
public class PolytomousKeyNodeDetailElement extends
		AbstractCdmDetailElement<PolytomousKeyNode> {

	private KeyStatementElement element_statement;

	private FeatureSelectionElement selection_feature;

	private TaxonSelectionElement selection_taxon;

	private PolytomousKeySelectionElement selection_subkey;

	private PolytomousKeyNodeSelectionElement selection_otherNode;

	private KeyStatementElement element_question;

	public PolytomousKeyNodeDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement) {
		super(formFactory, formElement);
	}

	@Override
	protected void createControls(ICdmFormElement formElement,
			PolytomousKeyNode entity, int style) {
		if (!entity.isLeaf()) {
			NumberWithLabelElement number_nodeNumber = formFactory
					.createIntegerTextWithLabelElement(formElement,
							"Node Number", entity.getNodeNumber(), style);
			number_nodeNumber.setEnabled(false);
		}

		if (entity.getParent() != null) {
			PolytomousKeyNode parent = entity.getParent();

			element_question = formFactory.createKeyStatementElement(
					formElement, "Question", parent.getQuestion(), 50, style);

			selection_feature = (FeatureSelectionElement) formFactory
					.createSelectionElement(SelectionType.FEATURE,
							getConversationHolder(), formElement, "Feature",
							parent.getFeature(),
							FeatureSelectionElement.DEFAULT, style);
		}

		element_statement = formFactory.createKeyStatementElement(formElement,
				"Statement", entity.getStatement(), 50, style);

		if (entity.isLeaf()) {
			selection_taxon = (TaxonSelectionElement) formFactory
					.createSelectionElement(SelectionType.TAXON,
							getConversationHolder(), formElement, "Taxon",
							entity.getTaxon(), TaxonSelectionElement.DELETABLE,
							style);
		}

		selection_subkey = (PolytomousKeySelectionElement) formFactory
				.createSelectionElement(SelectionType.POLYTOMOUS_KEY,
						getConversationHolder(), formElement, "Subkey",
						entity.getSubkey(),
						PolytomousKeySelectionElement.DEFAULT, style);

		selection_otherNode = (PolytomousKeyNodeSelectionElement) formFactory
				.createSelectionElement(SelectionType.POLYTOMOUS_KEY_NODE,
						getConversationHolder(), formElement, "Other Node",
						entity.getOtherNode(),
						PolytomousKeyNodeSelectionElement.DEFAULT, style);

		formFactory.createMultiLanguageTextElement(formElement,
				"Modifying Text", entity.getModifyingText(), 50, style);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.section.AbstractCdmDetailElement#handleEvent(java
	 * .lang.Object)
	 */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == element_question) {
			getEntity().getParent().setQuestion(
					element_question.getKeyStatement());
		} else if (eventSource == element_statement) {
			getEntity().setStatement(element_statement.getKeyStatement());
		} else if (eventSource == selection_feature) {
			getEntity().getParent().setFeature(selection_feature.getEntity());
		} else if (eventSource == selection_taxon) {
			getEntity().setTaxon(selection_taxon.getEntity());
		} else if (eventSource == selection_subkey) {
			getEntity().setSubkey(selection_subkey.getEntity());
		} else if (eventSource == selection_otherNode) {
			getEntity().setOtherNode(selection_otherNode.getEntity());
		}
	}
}
