// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.media;

import java.io.IOException;
import java.net.URI;
import java.util.Collection;

import org.apache.commons.lang.StringUtils;
import org.apache.http.HttpException;
import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.api.service.IMediaService;
import eu.etaxonomy.cdm.common.media.ImageInfo;
import eu.etaxonomy.cdm.model.media.ImageFile;
import eu.etaxonomy.cdm.model.media.MediaRepresentation;
import eu.etaxonomy.cdm.model.media.MediaRepresentationPart;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.EntityDetailType;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;

/**
 * <p>MediaRepresentationElement class.</p>
 *
 * @author n.hoffmann
 * @created Mar 24, 2010
 * @version 1.0
 */
public class MediaRepresentationElement extends AbstractEntityCollectionElement<MediaRepresentation> {

	private MediaRepresentationPartSection section_mediaRepresentationPart;
	private TextWithLabelElement text_mimeType;
	private TextWithLabelElement text_suffix;

	/**
	 * <p>Constructor for MediaRepresentationElement.</p>
	 *
	 * @param cdmFormFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param section a {@link eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection} object.
	 * @param element a {@link eu.etaxonomy.cdm.model.media.MediaRepresentation} object.
	 * @param removeListener a {@link org.eclipse.swt.events.SelectionListener} object.
	 * @param style a int.
	 */
	public MediaRepresentationElement(CdmFormFactory cdmFormFactory,
			AbstractFormSection section,
			MediaRepresentation element, SelectionListener removeListener,
			int style) {
		super(cdmFormFactory, section, element, removeListener, null, style);
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.section.AbstractEntityCollectionElement#createControls(eu.etaxonomy.taxeditor.forms.ICdmFormElement, int)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControls(ICdmFormElement element, int style) {
		text_mimeType = formFactory.createTextWithLabelElement(element, "Mime Type", null, style);
		text_suffix = formFactory.createTextWithLabelElement(element, "Suffix", null, style);
		section_mediaRepresentationPart = (MediaRepresentationPartSection) formFactory.createEntityDetailSection(EntityDetailType.MEDIAREPRESENTATIONPART, getConversationHolder(), element, style);
		section_mediaRepresentationPart.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY(2, 1));
	}

	/** {@inheritDoc} */
	@Override
	public void setEntity(MediaRepresentation element) {
		this.entity = element;
		section_mediaRepresentationPart.setEntity(element);
		text_mimeType.setText(element.getMimeType());
		text_suffix.setText(element.getSuffix());
	}
	
	/*
	 * (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionElement#handleEvent(java.lang.Object)
	 */
	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if(eventSource == text_mimeType){
			getEntity().setMimeType(text_mimeType.getText());
		}
		else if(eventSource == text_suffix){
			getEntity().setSuffix(text_suffix.getText());
		}
		// FIXME HACK automatically set the mime type to the first mediaRepresentationPart's mimetype
		else if(eventSource == section_mediaRepresentationPart){
			Collection<MediaRepresentationPart> imageFileElements = section_mediaRepresentationPart.getCollection(section_mediaRepresentationPart.getEntity());
			
			MediaRepresentationPart mediaRepresentationPart = imageFileElements.iterator().next();
			if(mediaRepresentationPart == null || !(mediaRepresentationPart instanceof ImageFile)){
				return;
			}
			ImageFile imageFile = (ImageFile) mediaRepresentationPart;

			URI uri = imageFile.getUri();
			if(uri == null){
				return;
			}
			try {
				ImageInfo imageInfo = ImageInfo.NewInstance(uri, 10000);
				String mimeType = imageInfo.getMimeType();
				text_mimeType.setText(mimeType);
				text_suffix.setText(imageInfo.getSuffix());	
			} catch (IOException e) {
				StoreUtil.error(getClass(), e);
			} catch (HttpException e) {
				StoreUtil.error(getClass(), e);
			}
		}
	}
	
	private String getMimeType(URI uri){
		return null;
	}
}
