// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.name;

import org.eclipse.jface.viewers.ISelectionProvider;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.DetailType;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailSection;
import eu.etaxonomy.taxeditor.ui.section.ITaxonBaseDetailSection;

/**
 * <p>NameDetailSection class.</p>
 *
 * @author n.hoffmann
 * @created 05.06.2009
 * @version 1.0
 */
public class NameDetailSection extends AbstractCdmDetailSection<NonViralName> implements ITaxonBaseDetailSection{

	private TaxonBase taxonBase;

	/**
	 * <p>Constructor for NameDetailSection.</p>
	 *
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param style a int.
	 * @param cdmFormFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param selectionProvider a {@link org.eclipse.jface.viewers.ISelectionProvider} object.
	 */
	public NameDetailSection(CdmFormFactory cdmFormFactory, ConversationHolder conversation, ICdmFormElement parentElement,
			ISelectionProvider selectionProvider, int style) {
		super(cdmFormFactory, conversation, parentElement, selectionProvider, style);
	}

	/** {@inheritDoc} */
	public void setTaxonBase(TaxonBase entity) {
		this.taxonBase = entity;
		NonViralName name = (NonViralName) HibernateProxyHelper.deproxy(entity.getName());
		setEntity(name);
	}

	/** {@inheritDoc} */
	@Override
	public String getHeading() {
		return "Scientific Name";
	}

	/** {@inheritDoc} */
	@Override
	protected DetailType getDetailType() {
		return DetailType.SCIENTIFICNAME;
	}

	/** {@inheritDoc} */
	@Override
	protected void setSectionTitle() {
		if(!isDisposed()){
			String title = "";
			if(getEntity() != null && (getEntity() instanceof NonViralName)){
				 title = ": " + ((NonViralName) getEntity()).getNameCache();
			}
			this.setText(getHeading() + title);
		}
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.ITaxonDetailSection#getTaxon(eu.etaxonomy.cdm.model.taxon.TaxonBase)
	 */
	@Override
	public TaxonBase getTaxonBase() {
		return taxonBase;
	}
	
}
