// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.name;

import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;

import eu.etaxonomy.cdm.model.name.NameRelationship;
import eu.etaxonomy.cdm.model.name.NameRelationshipType;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.TermComboType;
import eu.etaxonomy.taxeditor.ui.forms.RootElement;
import eu.etaxonomy.taxeditor.ui.selection.NameSelectionElement;
import eu.etaxonomy.taxeditor.ui.term.NameRelationshipTypeComboElement;

/**
 * <p>
 * NameRelationshipWizardPage class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Jun 1, 2010
 * @version 1.0
 */
public class NameRelationshipWizardPage extends WizardPage implements
		IPropertyChangeListener {

	private final CdmFormFactory formFactory;

	private NameSelectionElement selection_relatedTo;

	private NameRelationshipTypeComboElement combo_relationshipType;

	private final NameRelationshipDetailSection callingSection;

	private final TaxonNameBase entity;

	private NameRelationshipType type;

	private TaxonNameBase toName;

	private RootElement rootElement;

	/**
	 * <p>
	 * Constructor for NameRelationshipWizardPage.
	 * </p>
	 * 
	 * @param callingSection
	 *            a
	 *            {@link eu.etaxonomy.taxeditor.ui.section.name.NameRelationshipDetailSection}
	 *            object.
	 */
	protected NameRelationshipWizardPage(
			NameRelationshipDetailSection callingSection) {
		super("NameRelationshipWizardPage");
		setTitle("New Name Relationship");
		setDescription(callingSection.getEntity().getTitleCache());
		this.callingSection = callingSection;
		this.entity = callingSection.getEntity();
		this.formFactory = callingSection.getFormFactory();

		formFactory.addPropertyChangeListener(this);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets
	 * .Composite)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControl(Composite parent) {
		this.setPageComplete(false);

		Composite control = formFactory.createComposite(parent);

		control.setLayout(CdmFormFactory.LAYOUT(2, false));

		rootElement = new RootElement(formFactory, control);

		combo_relationshipType = (NameRelationshipTypeComboElement) formFactory
				.createTermComboElement(TermComboType.NAMERELATIONSHIP,
						rootElement, "Name Relationship Type", null, SWT.NULL);

		selection_relatedTo = (NameSelectionElement) formFactory
				.createSelectionElement(SelectionType.NAME,
						((NameRelationshipWizard) getWizard())
								.getConversationHolder(), rootElement,
						"Related to", null, NameSelectionElement.DEFAULT,
						SWT.NULL);

		setControl(control);
	}

	/**
	 * <p>
	 * getNameRelationship
	 * </p>
	 * 
	 * @return a {@link eu.etaxonomy.cdm.model.name.NameRelationship} object.
	 */
	public NameRelationship getNameRelationship() {
		return entity.addRelationshipToName(toName, type, null, null, null);
	}

	/** {@inheritDoc} */
	@Override
	public void propertyChange(PropertyChangeEvent event) {
		if (event == null) {
			return;
		}
		Object eventSource = event.getSource();
		if (eventSource == combo_relationshipType) {
			type = combo_relationshipType.getSelection();
		} else if (eventSource == selection_relatedTo) {
			toName = selection_relatedTo.getEntity();
		}

		boolean complete = type != null && toName != null;
		setPageComplete(complete);
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		rootElement.removeElements();
		formFactory.removePropertyChangeListener(this);
		super.dispose();
	}
}
