// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.name;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.ToolBarManager;
import org.eclipse.jface.viewers.ISelectionProvider;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Control;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.DetailType;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailSection;
import eu.etaxonomy.taxeditor.ui.section.ITaxonBaseDetailSection;

/**
 * <p>NonViralNameDetailSection class.</p>
 *
 * @author n.hoffmann
 * @created May 20, 2010
 * @version 1.0
 */
public class NonViralNameDetailSection extends AbstractCdmDetailSection<NonViralName>
		implements ITaxonBaseDetailSection {

	private TaxonBase taxonBase;

	/**
	 * <p>Constructor for NonViralNameDetailSection.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param selectionProvider a {@link org.eclipse.jface.viewers.ISelectionProvider} object.
	 * @param style a int.
	 */
	public NonViralNameDetailSection(CdmFormFactory formFactory, ConversationHolder conversation,
			ICdmFormElement parentElement, ISelectionProvider selectionProvider, int style) {
		super(formFactory, conversation, parentElement, selectionProvider, style);
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractCdmDetailSection#createToolbar()
	 */
	@Override
	protected Control createToolbar() {
		ToolBarManager toolBarManager = new ToolBarManager(SWT.FLAT);
		
		if(getEntity() != null && checkForMultipleNameUsages(getEntity())){
		
			Action cloneAction = new Action("Clone", Action.AS_PUSH_BUTTON){
				public void run() {
					boolean confirm = StoreUtil.confirmDialog("Confirm cloning", "Do you really want to clone the name?");
					
					if(confirm){
						NonViralName clonedName;
						clonedName = (NonViralName) getEntity().clone();
						setEntity(clonedName);
						taxonBase.setName(clonedName);
						taxonBase.generateTitle();
//						EditorUtil.getActiveMultiPageTaxonEditor().r
						firePropertyChangeEvent(new CdmPropertyChangeEvent(NonViralNameDetailSection.this, null));
					}
					
				};
			};
			
			cloneAction.setToolTipText("Clone the name if you do not want to edit the shared instance");
			
			toolBarManager.add(cloneAction);
		
		}
		return toolBarManager.createControl(this);
	}
	

	/**
	 * @param nonViralName 
	 * 
	 */
	private boolean checkForMultipleNameUsages(NonViralName nonViralName) {
		return nonViralName.getTaxonBases().size() != 1;
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractCdmDetailSection#getDetailType()
	 */
	/** {@inheritDoc} */
	@Override
	protected DetailType getDetailType() {
		return DetailType.NONVIRALNAME;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractCdmDetailSection#getHeading()
	 */
	/** {@inheritDoc} */
	@Override
	public String getHeading() {
		return "Name";
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.ITaxonDetailSection#setTaxon(eu.etaxonomy.cdm.model.taxon.TaxonBase)
	 */
	/** {@inheritDoc} */
	public void setTaxonBase(TaxonBase taxon) {
		taxonBase = taxon;
		NonViralName name = (NonViralName) HibernateProxyHelper.deproxy(taxon.getName());
		setEntity(name);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.ITaxonDetailSection#getTaxon(eu.etaxonomy.cdm.model.taxon.TaxonBase)
	 */
	@Override
	public TaxonBase getTaxonBase() {
		return taxonBase;
	}
}
