// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.name;

import java.net.URI;
import java.net.URISyntaxException;

import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.TaxonNameDescription;
import eu.etaxonomy.cdm.model.media.Media;
import eu.etaxonomy.cdm.model.media.MediaRepresentation;
import eu.etaxonomy.cdm.model.media.MediaRepresentationPart;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.ISelectableElement;
import eu.etaxonomy.taxeditor.ui.forms.SelectionArbitrator;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.openurl.IOpenUrlEnabled;
import eu.etaxonomy.taxeditor.ui.openurl.OpenUrlSelectorElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;

/**
 * <p>ProtologueElement class.</p>
 *
 * @author n.hoffmann
 * @created Nov 5, 2009
 * @version 1.0
 */
public class ProtologueElement extends AbstractEntityCollectionElement<DescriptionElementBase> implements ISelectableElement, IOpenUrlEnabled{

	private SelectionArbitrator selectionArbitrator;

	private TextWithLabelElement protologueUriText;
	private MediaRepresentationPart mediaRepresentationPart;
	private Media media;
	private MediaRepresentation mediaRepresentation;

	private OpenUrlSelectorElement element_openUrl;

	/**
	 * <p>Constructor for ProtologueElement.</p>
	 *
	 * @param element a {@link eu.etaxonomy.cdm.model.description.DescriptionElementBase} object.
	 * @param removeListener a {@link org.eclipse.swt.events.SelectionListener} object.
	 * @param style a int.
	 * @param cdmFormFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param formElement a {@link eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection} object.
	 */
	public ProtologueElement(CdmFormFactory cdmFormFactory, AbstractFormSection formElement, DescriptionElementBase element,
			SelectionListener removeListener, int style) {
		super(cdmFormFactory, formElement, element, removeListener, null, style);
		selectionArbitrator = cdmFormFactory.createSelectionArbitrator(this);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.entitysections.AbstractEntitySetElementComposite#createControls(org.eclipse.swt.widgets.Composite, int)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControls(ICdmFormElement element, int style) {
		protologueUriText = formFactory.createTextWithLabelElement(this, "Protologue URI", "", style);

		element_openUrl = formFactory.createOpenUrlSelectorElement(element, "Query BHL for Reference Image", this, style);
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.entitysections.AbstractEntitySetElementComposite#setElement(eu.etaxonomy.cdm.model.common.VersionableEntity)
	 */
	/** {@inheritDoc} */
	@Override
	public void setEntity(DescriptionElementBase element) {
		this.entity = element;
				
		if(element.getMedia().size() == 0){
			element.addMedia(Media.NewInstance());
		}
		media = element.getMedia().iterator().next();
		
		if(media.getRepresentations().size() == 0){
			media.addRepresentation(MediaRepresentation.NewInstance());
		}		
		mediaRepresentation = media.getRepresentations().iterator().next();
		
		if(mediaRepresentation.getParts().size() == 0){
			mediaRepresentation.addRepresentationPart(MediaRepresentationPart.NewInstance(null, null));
		}
		
		mediaRepresentationPart = mediaRepresentation.getParts().iterator().next();
		
		if(mediaRepresentationPart.getUri() != null){
			protologueUriText.setText(mediaRepresentationPart.getUri().toString());
		}
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.section.cdmdetail.ISelectableElement#getSelectionArbitrator()
	 */
	/**
	 * <p>Getter for the field <code>selectionArbitrator</code>.</p>
	 *
	 * @return a {@link eu.etaxonomy.taxeditor.ui.forms.SelectionArbitrator} object.
	 */
	public SelectionArbitrator getSelectionArbitrator() {
		return selectionArbitrator;
	}
	
	/*
	 * (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.AbstractEntityCollectionElement#handleEvent(java.lang.Object)
	 */
	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if(eventSource == protologueUriText){
			try {
				mediaRepresentationPart.setUri(new URI(protologueUriText.getText()));
			} catch (URISyntaxException e) {
				StoreUtil.warningDialog("Could not parse URI", getClass(), e.getMessage());
			}
		}	
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.openurl.IOpenUrlEnabled#setOpenUrl(java.net.URI)
	 */
	@Override
	public void setOpenUrl(URI uri) {
		protologueUriText.setText(uri.toString());
		firePropertyChangeEvent(new CdmPropertyChangeEvent(protologueUriText, null));
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.openurl.IOpenUrlEnabled#getReference()
	 */
	@Override
	public Reference getReference() {
		return (Reference) getName().getNomenclaturalReference();
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.openurl.IOpenUrlEnabled#getDetail()
	 */
	@Override
	public String getDetail() {
		return getName().getNomenclaturalMicroReference();
	}
	
	private TaxonNameBase getName(){
		TaxonNameDescription description = (TaxonNameDescription) entity.getInDescription();
		
		TaxonNameBase taxonName = description.getTaxonName();
		
		return taxonName;
	}
}
