// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.name;

import java.util.Collection;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.Feature;
import eu.etaxonomy.cdm.model.description.TaxonNameDescription;
import eu.etaxonomy.cdm.model.description.TextData;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;
import eu.etaxonomy.taxeditor.ui.section.ITaxonBaseDetailSection;

/**
 * <p>ProtologueSection class.</p>
 *
 * @author n.hoffmann
 * @created Nov 5, 2009
 * @version 1.0
 */
public class ProtologueSection extends AbstractEntityCollectionSection<TaxonNameBase, DescriptionElementBase> implements ITaxonBaseDetailSection{
	
	private TaxonBase taxonBase;

	/**
	 * <p>Constructor for ProtologueSection.</p>
	 *
	 * @param cdmFormFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param style a int.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 */
	public ProtologueSection(CdmFormFactory cdmFormFactory, ConversationHolder conversation, ICdmFormElement parentElement, int style) {
		super(cdmFormFactory, conversation, parentElement, "Protologues", style);
	}

	/** {@inheritDoc} */
	@Override
	public DescriptionElementBase createNewElement() {
		return TextData.NewInstance(Feature.PROTOLOGUE());
	}


	/** {@inheritDoc} */
	@Override
	public Collection<DescriptionElementBase> getCollection(
			TaxonNameBase entity) {
		return getTaxonNameDescription(entity).getElements();
	}


	/** {@inheritDoc} */
	@Override
	public String getEmptyString() {
		return "No protologues yet.";
	}


	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Create a new protologue";
	}

	/** {@inheritDoc} */
	@Override
	public void addElement(DescriptionElementBase element) {
		getTaxonNameDescription(getEntity()).addElement(element);
	}

	/** {@inheritDoc} */
	@Override
	public void removeElement(DescriptionElementBase element) {
		getTaxonNameDescription(getEntity()).removeElement(element);
	}

	/** {@inheritDoc} */
	public void setTaxonBase(TaxonBase entity) {
		this.taxonBase = entity;
		NonViralName name = (NonViralName) HibernateProxyHelper.deproxy(entity.getName());
		setEntity(name);
	}
	
	private TaxonNameDescription getTaxonNameDescription(TaxonNameBase name){
		// FIXME does not handle multiple name descriptions at the moment
		if(name.getDescriptions().size() == 0){
			name.addDescription(TaxonNameDescription.NewInstance(name));
		}
		return (TaxonNameDescription) name.getDescriptions().iterator().next();
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.ITaxonDetailSection#getTaxon(eu.etaxonomy.cdm.model.taxon.TaxonBase)
	 */
	@Override
	public TaxonBase getTaxonBase() {
		return taxonBase;
	}
}
