// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.name;

import java.util.Collection;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.name.NameTypeDesignation;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.name.Rank;
import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignation;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.name.TypeDesignationBase;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionSection;
import eu.etaxonomy.taxeditor.ui.section.ITaxonBaseDetailSection;

/**
 * <p>TypeDesignationSection class.</p>
 *
 * @author n.hoffmann
 * @created May 17, 2010
 * @version 1.0
 */
public class TypeDesignationSection extends AbstractEntityCollectionSection<TaxonNameBase, TypeDesignationBase> implements ITaxonBaseDetailSection {

	private TaxonBase taxonBase;

	/**
	 * <p>Constructor for TypeDesignationSection.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param style a int.
	 */
	public TypeDesignationSection(CdmFormFactory formFactory, ConversationHolder conversation,
			ICdmFormElement parentElement, int style) {
		super(formFactory, conversation, parentElement, "Type Designations", style);
	}
	
	/** {@inheritDoc} */
	@Override
	public void addElement(TypeDesignationBase element) {
		getEntity().addTypeDesignation(element, false);
	}

	/** {@inheritDoc} */
	@Override
	public TypeDesignationBase createNewElement() {
		if(isSpecimenType()){
			return SpecimenTypeDesignation.NewInstance();
		}else{
			return NameTypeDesignation.NewInstance();
		}
	}

	/** {@inheritDoc} */
	@Override
	public Collection<TypeDesignationBase> getCollection(TaxonNameBase entity) {
		return entity.getTypeDesignations();
	}

	/** {@inheritDoc} */
	@Override
	public String getEmptyString() {
		return "No type designations yet.";
	}

	/** {@inheritDoc} */
	@Override
	protected String getTooltipString() {
		return "Add a type designation";
	}

	/** {@inheritDoc} */
	@Override
	public void removeElement(TypeDesignationBase element) {
		getEntity().removeTypeDesignation(element);
	}

	/*
	 * (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.ITaxonDetailSection#setTaxon(eu.etaxonomy.cdm.model.taxon.TaxonBase)
	 */
	/** {@inheritDoc} */
	public void setTaxonBase(TaxonBase entity) {
		this.taxonBase = entity;
		NonViralName name = (NonViralName) HibernateProxyHelper.deproxy(entity.getName());
		setEntity(name);
	}
	
	private boolean isSpecimenType(){
		Rank rank = getEntity().getRank();
		return rank.isSpecies() || rank.isInfraSpecific();
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.ITaxonDetailSection#getTaxon(eu.etaxonomy.cdm.model.taxon.TaxonBase)
	 */
	@Override
	public TaxonBase getTaxonBase() {
		return taxonBase;
	}
}
