// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.occurrence;

import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.model.common.EventBase;
import eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.forms.TimePeriodElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;
import eu.etaxonomy.taxeditor.ui.selection.AgentSelectionElement;

/**
 * <p>
 * Abstract AbstractEventDetailElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Oct 14, 2010
 * @version 1.0
 */
public abstract class AbstractEventDetailElement<T extends EventBase> extends
		AbstractEntityCollectionElement<T> {

	protected AgentSelectionElement selection_agent;
	protected TextWithLabelElement text_description;
	protected TimePeriodElement element_timePeriod;

	/**
	 * <p>
	 * Constructor for AbstractEventDetailElement.
	 * </p>
	 * 
	 * @param formFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param section
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection}
	 *            object.
	 * @param entity
	 *            a T object.
	 * @param removeListener
	 *            a {@link org.eclipse.swt.events.SelectionListener} object.
	 * @param style
	 *            a int.
	 * @param <T>
	 *            a T object.
	 */
	public AbstractEventDetailElement(CdmFormFactory formFactory,
			AbstractFormSection section, T entity,
			SelectionListener removeListener, int style) {
		super(formFactory, section, entity, removeListener, null, style);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.section.AbstractEntityCollectionElement#setEntity
	 * (java.lang.Object)
	 */
	/** {@inheritDoc} */
	@Override
	public void setEntity(T entity) {
		selection_agent.setEntity(entity.getActor());
		text_description.setText(entity.getDescription());
		element_timePeriod.setEntity(entity.getTimeperiod());
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.section.AbstractEntityCollectionElement#createControls
	 * (eu.etaxonomy.taxeditor.forms.ICdmFormElement, int)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControls(ICdmFormElement element, int style) {
		selection_agent = (AgentSelectionElement) formFactory
				.createSelectionElement(SelectionType.AGENT,
						getConversationHolder(), element, "Actor", null,
						AgentSelectionElement.DEFAULT, style);
		element_timePeriod = formFactory.createTimePeriodElement(element,
				"Time Period", null, style);
		text_description = formFactory.createTextWithLabelElement(element,
				"Description", null, style);
	}

}
