// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.occurrence;

import eu.etaxonomy.cdm.model.occurrence.Collection;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.forms.ToggleableTextElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.CollectionSelectionElement;
import eu.etaxonomy.taxeditor.ui.selection.InstitutionSelectionElement;

/**
 * <p>
 * CollectionDetailElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Oct 13, 2010
 * @version 1.0
 */
public class CollectionDetailElement extends
		AbstractCdmDetailElement<Collection> {

	private ToggleableTextElement text_titleCache;

	private TextWithLabelElement text_code;

	private TextWithLabelElement text_codeStandard;

	private TextWithLabelElement text_name;

	private TextWithLabelElement text_townOrLocation;

	private InstitutionSelectionElement selection_institute;

	private CollectionSelectionElement selection_superCollection;

	/**
	 * <p>
	 * Constructor for CollectionDetailElement.
	 * </p>
	 * 
	 * @param formFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement}
	 *            object.
	 */
	public CollectionDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement) {
		super(formFactory, formElement);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.section.AbstractCdmDetailElement#createControls
	 * (eu.etaxonomy.taxeditor.forms.ICdmFormElement,
	 * eu.etaxonomy.cdm.model.common.IAnnotatableEntity, int)
	 */
	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
			Collection entity, int style) {
		text_titleCache = formFactory.createToggleableTextField(formElement,
				"Title Cache", entity.getTitleCache(),
				entity.isProtectedTitleCache(), style);

		text_code = formFactory.createTextWithLabelElement(formElement, "Code",
				entity.getCode(), style);
		text_codeStandard = formFactory.createTextWithLabelElement(formElement,
				"Code Standard", entity.getCodeStandard(), style);
		text_name = formFactory.createTextWithLabelElement(formElement, "Name",
				entity.getName(), style);
		text_townOrLocation = formFactory.createTextWithLabelElement(
				formElement, "Town Or Location", entity.getTownOrLocation(),
				style);
		selection_institute = (InstitutionSelectionElement) formFactory
				.createSelectionElement(SelectionType.INSTITUTION,
						getConversationHolder(), formElement, "Institute",
						entity.getInstitute(),
						InstitutionSelectionElement.DEFAULT, style);
		selection_superCollection = (CollectionSelectionElement) formFactory
				.createSelectionElement(SelectionType.COLLECTION,
						getConversationHolder(), formElement,
						"Super Collection", entity.getSuperCollection(),
						CollectionSelectionElement.DEFAULT, style);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.section.AbstractCdmDetailElement#handleEvent(java
	 * .lang.Object)
	 */
	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == text_titleCache) {
			getEntity().setTitleCache(text_titleCache.getText(),
					text_titleCache.getState());
		} else if (eventSource == text_code) {
			getEntity().setCode(text_code.getText());
		} else if (eventSource == text_codeStandard) {
			getEntity().setCodeStandard(text_codeStandard.getText());
		} else if (eventSource == text_name) {
			getEntity().setName(text_name.getText());
		} else if (eventSource == text_townOrLocation) {
			getEntity().setTownOrLocation(text_townOrLocation.getText());
		} else if (eventSource == selection_institute) {
			getEntity().setInstitute(selection_institute.getSelection());
		} else if (eventSource == selection_superCollection) {
			getEntity().setSuperCollection(
					selection_superCollection.getSelection());
		}
	}

}
