// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.occurrence;

import org.eclipse.ui.forms.widgets.Section;

import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.cdm.api.facade.MethodNotSupportedByDerivedUnitTypeException;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.EntityDetailType;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.TermComboType;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.NameSelectionElement;
import eu.etaxonomy.taxeditor.ui.term.PreservationMethodComboElement;

/**
 * <p>
 * DerivedUnitBaseDetailElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Jun 24, 2010
 * @version 1.0
 */
public class DerivedUnitBaseDetailElement extends
		AbstractCdmDetailElement<DerivedUnitFacade> {

	private TextWithLabelElement text_derivedUnitDefinitions;

	private TextWithLabelElement text_accessionNumber;

	private TextWithLabelElement text_catalogNumber;

	private NameSelectionElement selection_storedUnder;

	private TextWithLabelElement text_exsicatum;

	private PreservationMethodComboElement combo_preservationMethod;

	private SpecimenCollectionDetailSection section_duplicates;

	private SourceCollectionDetailSection section_source;

	private TextWithLabelElement text_collectorsNumber;

	/**
	 * <p>
	 * Constructor for DerivedUnitBaseDetailElement.
	 * </p>
	 * 
	 * @param formFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement}
	 *            object.
	 */
	public DerivedUnitBaseDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement) {
		super(formFactory, formElement);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
			DerivedUnitFacade entity, int style) {
		// Disable for now
		// text_derivedUnitDefinitions =
		// formFactory.createTextWithLabelElement(formElement,
		// "Specimen Definition",
		// facade.getDerivedUnitDefinition(CdmStore.getDefaultLanguage()),
		// style);
		text_accessionNumber = formFactory.createTextWithLabelElement(
				formElement, "Accession Number", entity.getAccessionNumber(),
				style);
		text_catalogNumber = formFactory
				.createTextWithLabelElement(formElement, "Catalog Number",
						entity.getCatalogNumber(), style);

		try {
			combo_preservationMethod = (PreservationMethodComboElement) formFactory
					.createTermComboElement(TermComboType.PRESERVATION_METHOD,
							formElement, "Preservation Method",
							entity.getPreservationMethod(), style);
		} catch (MethodNotSupportedByDerivedUnitTypeException e) {
			// we ignore this
			StoreUtil.info(e.getMessage());
		}
		selection_storedUnder = (NameSelectionElement) formFactory
				.createSelectionElement(SelectionType.NAME,
						getConversationHolder(), formElement, "Stored Under",
						entity.getStoredUnder(), NameSelectionElement.DEFAULT,
						style);

		try {
			text_exsicatum = formFactory.createTextWithLabelElement(
					formElement, "Exsiccatum", entity.getExsiccatum(), style);
		} catch (MethodNotSupportedByDerivedUnitTypeException e) {
			// we ignore this
			StoreUtil.info(e.getMessage());
		}

		section_duplicates = (SpecimenCollectionDetailSection) formFactory
				.createEntityDetailSection(
						EntityDetailType.SPECIMEN_COLLECTION,
						getConversationHolder(), formElement, Section.TWISTIE);
		section_duplicates
				.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY(2, 1));
		section_duplicates.setEntity(entity);

		section_source = (SourceCollectionDetailSection) formFactory
				.createEntityDetailSection(
						EntityDetailType.IDENTIFIABLE_SOURCE_COLLECTION,
						getConversationHolder(), formElement, Section.TWISTIE);
		section_source.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY(2, 1));
		section_source.setEntity(entity);
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == text_derivedUnitDefinitions) {
			getEntity().addDerivedUnitDefinition(
					text_derivedUnitDefinitions.getText(),
					CdmStore.getDefaultLanguage());
		} else if (eventSource == text_accessionNumber) {
			getEntity().setAccessionNumber(text_accessionNumber.getText());
		} else if (eventSource == text_catalogNumber) {
			getEntity().setCatalogNumber(text_catalogNumber.getText());
		} else if (eventSource == combo_preservationMethod) {
			try {
				getEntity().setPreservationMethod(
						combo_preservationMethod.getSelection());
			} catch (MethodNotSupportedByDerivedUnitTypeException e) {
				StoreUtil
						.errorDialog(
								"MethodNotSupportedByDerivedUnitTypeException",
								this,
								"MethodNotSupportedByDerivedUnitTypeException when trying to set preservation method for derive unit",
								e);
			}
		} else if (eventSource == selection_storedUnder) {
			getEntity().setStoredUnder(selection_storedUnder.getEntity());
		} else if (eventSource == text_exsicatum) {
			try {
				getEntity().setExsiccatum(text_exsicatum.getText());
			} catch (Exception e) {
				StoreUtil.error(this.getClass(), e);
			}
		}
	}
}
