// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.occurrence;

import org.eclipse.ui.forms.widgets.Section;

import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.cdm.api.facade.DerivedUnitFacadeConfigurator;
import eu.etaxonomy.cdm.api.facade.DerivedUnitFacadeNotSupportedException;
import eu.etaxonomy.cdm.model.occurrence.DerivedUnitBase;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.DetailType;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailSection;

/**
 * <p>DerivedUnitFacadeDetailElement class.</p>
 *
 * @author n.hoffmann
 * @created Jun 17, 2010
 * @version 1.0
 */
public class DerivedUnitFacadeDetailElement extends AbstractCdmDetailElement<DerivedUnitBase> {
	
	private DerivedUnitFacade facade;

	private DerivedUnitFacadeConfigurator configurator;

	private GeneralDetailSection section_general;
	private GatheringEventDetailSection section_gatheringEvent;
	private DerivedUnitBaseDetailSection section_derivedUnitBase;
	private FieldObservationDetailSection section_fieldObservation;

	/**
	 * <p>Constructor for DerivedUnitFacadeDetailElement.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param formElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 */
	public DerivedUnitFacadeDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement) {
		super(formFactory, formElement);
		configurator = DerivedUnitFacadeConfigurator.NewInstance();
		configurator.setMoveDerivedUnitMediaToGallery(true);
		configurator.setMoveFieldObjectMediaToGallery(true);
	}
	
	/** {@inheritDoc} */
	@Override
	public void setEntity(DerivedUnitBase entity) {
		super.setEntity(entity);
		try {
			facade = DerivedUnitFacade.NewInstance(entity, configurator);
			
			section_general.setEntity(facade);
			section_derivedUnitBase.setEntity(facade);
			section_gatheringEvent.setEntity(facade);
			section_fieldObservation.setEntity(facade);
			
		} catch (DerivedUnitFacadeNotSupportedException e) {
			StoreUtil.errorDialog("Error", this, "SpecimenFacadeNotSupportedException while inititating SpecimenFacade", e);
		}
	}
	
	/** {@inheritDoc} */
	@Override
	public void removeElements() {
		super.removeElements();
		if(section_general != null){
			removeControl(section_general);
			section_general.dispose();
			section_general = null;
		}
		if(section_derivedUnitBase != null){
			removeControl(section_derivedUnitBase);
			section_derivedUnitBase.dispose();
			section_derivedUnitBase = null;
		}
		if(section_gatheringEvent != null){
			removeControl(section_gatheringEvent);
			section_gatheringEvent.dispose();
			section_gatheringEvent = null;
		}
		if(section_fieldObservation != null){
			removeControl(section_fieldObservation);
			section_fieldObservation.dispose();
			section_fieldObservation = null;
		}
	}
	
	/** {@inheritDoc} */
	@Override
	public DerivedUnitBase getEntity() {
		throw new IllegalArgumentException("Should not be called");
	}
	
	/**
	 * <p>Getter for the field <code>facade</code>.</p>
	 *
	 * @return a {@link eu.etaxonomy.cdm.api.facade.DerivedUnitFacade} object.
	 */
	public DerivedUnitFacade getFacade(){
		return facade;
	}
	
	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
			DerivedUnitBase entity, int style) {
		
		section_general = (GeneralDetailSection) formFactory.createCdmDetailSection(DetailType.DERIVED_UNIT_GENERAL, getConversationHolder(), formElement, null, Section.TWISTIE | Section.EXPANDED);
		section_general.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY(2, 1));
		addControl(section_general);
		addElement(section_general);
		
		section_gatheringEvent = (GatheringEventDetailSection) formFactory.createCdmDetailSection(DetailType.GATHERING_EVENT, getConversationHolder(), formElement, null, Section.TWISTIE);
		section_gatheringEvent.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY(2, 1));
		addControl(section_gatheringEvent);
		addElement(section_gatheringEvent);
		
		section_fieldObservation = (FieldObservationDetailSection) formFactory.createCdmDetailSection(DetailType.FIELD_OBSERVATION, getConversationHolder(), formElement, null, Section.TWISTIE);
		section_fieldObservation.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY(2, 1));
		addControl(section_fieldObservation);
		addElement(section_fieldObservation);
		
		section_derivedUnitBase = (DerivedUnitBaseDetailSection) formFactory.createCdmDetailSection(DetailType.DERIVED_UNIT, getConversationHolder(), formElement, null, Section.TWISTIE);
		section_derivedUnitBase.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY(2, 1));
		addControl(section_derivedUnitBase);
		addElement(section_derivedUnitBase);
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if(eventSource == section_derivedUnitBase || eventSource == section_gatheringEvent || eventSource == section_fieldObservation){
			if(getParentElement() instanceof AbstractCdmDetailSection)
				((AbstractCdmDetailSection) getParentElement()).updateTitle();
		}
	}
}
