// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.occurrence;

import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.LanguageStringWithLabelElement;
import eu.etaxonomy.taxeditor.ui.forms.NumberWithLabelElement;
import eu.etaxonomy.taxeditor.ui.forms.PointElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.forms.TimePeriodElement;
import eu.etaxonomy.taxeditor.ui.forms.ToggleableTextElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.AgentSelectionElement;
import eu.etaxonomy.taxeditor.ui.selection.CollectionSelectionElement;
import eu.etaxonomy.taxeditor.ui.selection.NamedAreaSelectionElement;

/**
 * @author n.hoffmann
 * @created Dec 16, 2010
 * @version 1.0
 */
public class GeneralDetailElement extends
		AbstractCdmDetailElement<DerivedUnitFacade> {

	private ToggleableTextElement toggleableText_titleCache;

	private NamedAreaSelectionElement selection_country;
	private LanguageStringWithLabelElement languageText_locality;
	private PointElement element_point;
	private NumberWithLabelElement number_elevation;
	private TimePeriodElement element_date;
	private AgentSelectionElement selection_collector;
	private TextWithLabelElement text_collectingNumber;
	private CollectionSelectionElement selection_collection;
	private TextWithLabelElement text_barcode;

	/**
	 * @param formFactory
	 * @param formElement
	 */
	public GeneralDetailElement(CdmFormFactory formFactory,
			ICdmFormElement formElement) {
		super(formFactory, formElement);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.section.AbstractCdmDetailElement#createControls
	 * (eu.etaxonomy.taxeditor.forms.ICdmFormElement, java.lang.Object, int)
	 */
	@Override
	protected void createControls(ICdmFormElement formElement,
			DerivedUnitFacade entity, int style) {
		toggleableText_titleCache = formFactory.createToggleableTextField(
				formElement, "Title Cache", entity.getTitleCache(),
				entity.isProtectedTitleCache(), style);

		selection_country = formFactory.createNamedAreaSelectionElement(
				formElement, getConversationHolder(), "Country",
				entity.getCountry(), style);
		languageText_locality = formFactory
				.createLanguageStringWithLabelElement(formElement, "Locality",
						entity.getLocality(), style);
		element_point = formFactory.createPointElement(formElement,
				entity.getExactLocation(), style);
		number_elevation = formFactory.createIntegerTextWithLabelElement(
				formElement, "Absolute Elevation (m)",
				entity.getAbsoluteElevation(), style);
		element_date = formFactory.createTimePeriodElement(formElement, "Date",
				entity.getGatheringPeriod(), style);
		selection_collector = (AgentSelectionElement) formFactory
				.createSelectionElement(SelectionType.AGENT,
						getConversationHolder(), formElement, "Collector",
						entity.getCollector(), AgentSelectionElement.DEFAULT,
						style);
		text_collectingNumber = formFactory.createTextWithLabelElement(formElement,
				"Collecting number", entity.getFieldNumber(), style);
		selection_collection = (CollectionSelectionElement) formFactory
				.createSelectionElement(SelectionType.COLLECTION,
						getConversationHolder(), formElement, "Collection",
						entity.getCollection(),
						CollectionSelectionElement.DEFAULT, style);
		text_barcode = formFactory.createTextWithLabelElement(formElement,
				"Barcode", entity.getBarcode(), style);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.section.AbstractCdmDetailElement#handleEvent(java
	 * .lang.Object)
	 */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == toggleableText_titleCache) {
			getEntity().setTitleCache(toggleableText_titleCache.getText(),
					toggleableText_titleCache.getState());
		} else if (eventSource == selection_country) {
			getEntity().setCountry(selection_country.getSelection());
		} else if (eventSource == languageText_locality) {
			getEntity().setLocality(languageText_locality.getLanguageString());
		} else if (eventSource == element_point) {
			getEntity().setExactLocation(element_point.getPoint());
		} else if (eventSource == number_elevation) {
			getEntity().setAbsoluteElevation(number_elevation.getInteger());
		} else if (eventSource == element_date) {
			getEntity().setGatheringPeriod(element_date.getTimePeriod());
		} else if (eventSource == selection_collector) {
			getEntity().setCollector(selection_collector.getSelection());
		} else if (eventSource == text_collectingNumber) {
			getEntity().setFieldNumber(text_collectingNumber.getText());
		} else if (eventSource == selection_collection) {
			getEntity().setCollection(selection_collection.getSelection());
		} else if (eventSource == text_barcode) {
			getEntity().setBarcode(text_barcode.getText());
		}

		if (eventSource != toggleableText_titleCache) {
			toggleableText_titleCache.setText(getEntity().getTitleCache());
		}
	}

}
