// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.reference;

import org.apache.log4j.Logger;

import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.ReferenceSelectionElement;

/**
 * <p>
 * NomenclaturalReferenceDetailElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Mar 12, 2010
 * @version 1.0
 */
public class NomenclaturalReferenceDetailElement extends
		AbstractCdmDetailElement<TaxonNameBase> {

	private static final Logger logger = Logger
			.getLogger(NomenclaturalReferenceDetailElement.class);
	private ReferenceSelectionElement selection_nomenclaturalReference;
	private TextWithLabelElement text_referenceDetail;

	/**
	 * <p>
	 * Constructor for NomenclaturalReferenceDetailElement.
	 * </p>
	 * 
	 * @param cdmFormFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement}
	 *            object.
	 * @param style
	 *            a int.
	 */
	public NomenclaturalReferenceDetailElement(CdmFormFactory cdmFormFactory,
			ICdmFormElement formElement, int style) {
		super(cdmFormFactory, formElement);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
			TaxonNameBase entity, int style) {
		selection_nomenclaturalReference = (ReferenceSelectionElement) formFactory
				.createSelectionElement(SelectionType.REFERENCE,
						getConversationHolder(), formElement, "Reference",
						entity.getNomenclaturalReference(),
						ReferenceSelectionElement.DEFAULT, style);
		text_referenceDetail = formFactory.createTextWithLabelElement(
				formElement, "Reference Detail",
				entity.getNomenclaturalMicroReference(), style);
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == selection_nomenclaturalReference) {
			getEntity().setNomenclaturalReference(
					selection_nomenclaturalReference.getSelection());
		} else if (eventSource == text_referenceDetail) {
			getEntity().setNomenclaturalMicroReference(
					text_referenceDetail.getText());
		}
	}
}
