// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.reference;

import org.eclipse.jface.viewers.ISelectionProvider;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.DetailType;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailSection;
import eu.etaxonomy.taxeditor.ui.section.ITaxonBaseDetailSection;

/**
 * <p>ReferenceBaseDetailSection class.</p>
 *
 * @author n.hoffmann
 * @created 05.06.2009
 * @version 1.0
 */
public class ReferenceDetailSection extends AbstractCdmDetailSection<Reference> implements ITaxonBaseDetailSection{
	
	private TaxonBase taxonBase;

	/**
	 * <p>Constructor for ReferenceBaseDetailSection.</p>
	 *
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param style a int.
	 * @param cdmFormFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param conversation a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder} object.
	 * @param selectionProvider a {@link org.eclipse.jface.viewers.ISelectionProvider} object.
	 */
	public ReferenceDetailSection(CdmFormFactory cdmFormFactory, ConversationHolder conversation, ICdmFormElement parentElement,
			ISelectionProvider selectionProvider, int style) {
		super(cdmFormFactory, conversation, parentElement, selectionProvider, style);
	}

	/*
	 * (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.ITaxonDetailSection#setTaxon(eu.etaxonomy.cdm.model.taxon.TaxonBase)
	 */
	/** {@inheritDoc} */
	public void setTaxonBase(TaxonBase entity) {
		this.taxonBase = entity;
		NonViralName name = (NonViralName) HibernateProxyHelper.deproxy(entity.getName());
		
		Reference reference = (Reference) HibernateProxyHelper.deproxy(name.getNomenclaturalReference());
		
		setEntity(reference);
	}

	/*
	 * (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.section.cdmdetail.AbstractCdmDetailSection#getHeading()
	 */
	/** {@inheritDoc} */
	@Override
	public String getHeading() {
		return "Reference";
	}

	/** {@inheritDoc} */
	@Override
	protected DetailType getDetailType() {
		return DetailType.REFERENCEBASE;
	}	
	
	/** {@inheritDoc} */
	@Override
	public void refresh() {
		super.refresh();
		StoreUtil.refreshDetailsViewer();
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.section.ITaxonDetailSection#getTaxon(eu.etaxonomy.cdm.model.taxon.TaxonBase)
	 */
	@Override
	public TaxonBase getTaxonBase() {
		return taxonBase;
	}
	
}
