// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.supplemental;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.model.common.ReferencedEntityBase;
import eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;
import eu.etaxonomy.taxeditor.ui.selection.ReferenceSelectionElement;

/**
 * <p>
 * Abstract AbstractReferencedEntityElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Mar 25, 2010
 * @version 1.0
 */
public abstract class AbstractReferencedEntityElement<T extends ReferencedEntityBase>
		extends AbstractEntityCollectionElement<T> {

	protected ReferenceSelectionElement selection_reference;
	protected TextWithLabelElement text_referenceDetail;

	protected TextWithLabelElement text_originaleNameString;

	private boolean hasOriginalNameString = false;

	/**
	 * <p>
	 * Constructor for AbstractReferencedEntityElement.
	 * </p>
	 * 
	 * @param formFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param section
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection}
	 *            object.
	 * @param entity
	 *            a T object.
	 * @param removeListener
	 *            a {@link org.eclipse.swt.events.SelectionListener} object.
	 * @param style
	 *            a int.
	 * @param <T>
	 *            a T object.
	 */
	public AbstractReferencedEntityElement(CdmFormFactory formFactory,
			AbstractFormSection section, T entity,
			SelectionListener removeListener, int style) {
		super(formFactory, section, entity, removeListener, null, style);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.forms.section.AbstractEntityCollectionElement#
	 * createControls(eu.etaxonomy.taxeditor.forms.ICdmFormElement, int)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControls(ICdmFormElement formElement, int style) {
		selection_reference = (ReferenceSelectionElement) formFactory
				.createSelectionElement(SelectionType.REFERENCE,
						getConversationHolder(), formElement, "Reference",
						null, ReferenceSelectionElement.DEFAULT, style);
		text_referenceDetail = formFactory.createTextWithLabelElement(
				formElement, "Reference Detail", null, SWT.NULL);
		if (hasOriginalNameString)
			text_originaleNameString = formFactory.createTextWithLabelElement(
					formElement, "Original Name", null, SWT.NULL);
	}

	/**
	 * <p>
	 * setEntity
	 * </p>
	 * 
	 * @param entity
	 *            a T object.
	 */
	@Override
	public void setEntity(T entity) {
		this.entity = entity;

		selection_reference.setEntity(entity.getCitation());
		text_referenceDetail.setText(entity.getCitationMicroReference());
		if (hasOriginalNameString)
			text_originaleNameString.setText(entity.getOriginalNameString());
		// // remove old listeners
		// clearEditButtonSelectionListener();
		//
		// addEditButtonSelectionListener(new
		// BulkEditorOpeningSelectionListener(entity.getCitation()));
		//
	};

	//
	// public void addEditButtonSelectionListener(SelectionListener listener){
	// selection_reference.addEditButtonSelectionListener(listener);
	// }
	//
	// public void removeEditButtonSelectionListener(SelectionListener
	// listener){
	// selection_reference.removeEditorButtonSelectionListener(listener);
	// }
	//
	// public void clearEditButtonSelectionListener(){
	// selection_reference.clearEditButtonSelectionListener();
	// }

	/**
	 * <p>
	 * Setter for the field <code>hasOriginalNameString</code>.
	 * </p>
	 * 
	 * @param hasOriginalNameString
	 *            a boolean.
	 */
	public void setHasOriginalNameString(boolean hasOriginalNameString) {
		this.hasOriginalNameString = hasOriginalNameString;
	}

	/**
	 * <p>
	 * hasOriginalNameString
	 * </p>
	 * 
	 * @return a boolean.
	 */
	public boolean hasOriginalNameString() {
		return hasOriginalNameString;
	}
}
