/**
 * 
 */
package eu.etaxonomy.taxeditor.ui.section.supplemental;

import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.model.common.Credit;
import eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;
import eu.etaxonomy.taxeditor.ui.selection.AgentSelectionElement;

/**
 * <p>
 * CreditElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Nov 16, 2009
 * @version 1.0
 */
public class CreditElement extends AbstractEntityCollectionElement<Credit> {

	private AgentSelectionElement agentSelection;
	private TextWithLabelElement text;

	/**
	 * <p>
	 * Constructor for CreditElement.
	 * </p>
	 * 
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection}
	 *            object.
	 * @param style
	 *            a int.
	 * @param cdmFormFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param credit
	 *            a {@link eu.etaxonomy.cdm.model.common.Credit} object.
	 * @param removeListener
	 *            a {@link org.eclipse.swt.events.SelectionListener} object.
	 */
	public CreditElement(CdmFormFactory cdmFormFactory,
			AbstractFormSection formElement, Credit credit,
			SelectionListener removeListener, int style) {
		super(cdmFormFactory, formElement, credit, removeListener, null, style);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.forms.entitysections.AbstractEntitySetElementComposite
	 * #createControls(org.eclipse.swt.widgets.Composite, int)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControls(ICdmFormElement element, int style) {
		agentSelection = (AgentSelectionElement) formFactory
				.createSelectionElement(SelectionType.AGENT,
						getConversationHolder(), this, "Agent", null,
						AgentSelectionElement.DEFAULT, style);
		text = formFactory.createMultilineTextWithLabel(this, "Text", 100,
				style);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.forms.entitysections.AbstractEntitySetElementComposite
	 * #setElement(eu.etaxonomy.cdm.model.common.AnnotatableEntity)
	 */
	/** {@inheritDoc} */
	@Override
	public void setEntity(Credit element) {
		this.entity = element;

		agentSelection.setEntity(element.getAgent());
		text.setText(element.getText());
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == agentSelection) {
			entity.setAgent(agentSelection.getSelection());
		} else if (eventSource == text) {
			entity.setText(text.getText());
		}
	}
}
