/**
 * 
 */
package eu.etaxonomy.taxeditor.ui.section.supplemental;

import org.eclipse.swt.events.SelectionListener;

import eu.etaxonomy.cdm.model.agent.AgentBase;
import eu.etaxonomy.cdm.model.media.Rights;
import eu.etaxonomy.cdm.model.media.RightsTerm;
import eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.TermComboType;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractEntityCollectionElement;
import eu.etaxonomy.taxeditor.ui.selection.AbstractSelectionElement;
import eu.etaxonomy.taxeditor.ui.selection.AgentSelectionElement;
import eu.etaxonomy.taxeditor.ui.term.AbstractTermComboElement;

/**
 * <p>
 * RightsElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Nov 16, 2009
 * @version 1.0
 */
public class RightsElement extends AbstractEntityCollectionElement<Rights> {

	/**
	 * <p>
	 * Constructor for RightsElement.
	 * </p>
	 * 
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection}
	 *            object.
	 * @param element
	 *            a {@link eu.etaxonomy.cdm.model.media.Rights} object.
	 * @param removeListener
	 *            a {@link org.eclipse.swt.events.SelectionListener} object.
	 * @param style
	 *            a int.
	 * @param cdmFormFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 */
	public RightsElement(CdmFormFactory cdmFormFactory,
			AbstractFormSection formElement, Rights element,
			SelectionListener removeListener, int style) {
		super(cdmFormFactory, formElement, element, removeListener, null, style);
	}

	private AbstractTermComboElement<RightsTerm> combo_rightsType;
	private AbstractSelectionElement<AgentBase> selection_agent;
	private TextWithLabelElement text;

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.forms.entitysections.AbstractEntitySetElementComposite
	 * #createControls(org.eclipse.swt.widgets.Composite, int)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControls(ICdmFormElement element, int style) {
		combo_rightsType = formFactory.createTermComboElement(
				TermComboType.RIGHTSTYPE, this, "Rights Type", null, style);
		selection_agent = formFactory.createSelectionElement(
				SelectionType.AGENT, getConversationHolder(), this, "Agent",
				null, AgentSelectionElement.DEFAULT, style);
		text = formFactory.createMultilineTextWithLabel(this, "Text", 100,
				style);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.forms.entitysections.AbstractEntitySetElementComposite
	 * #setElement(eu.etaxonomy.cdm.model.common.VersionableEntity)
	 */
	/** {@inheritDoc} */
	@Override
	public void setEntity(Rights element) {
		this.entity = element;
		combo_rightsType.setSelection(element.getType());
		selection_agent.setEntity(element.getAgent());
		text.setText(element.getText());
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.section.AbstractEntityCollectionElement#handleEvent
	 * (java.lang.Object)
	 */
	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource == combo_rightsType) {
			entity.setType(combo_rightsType.getSelection());
		} else if (eventSource == selection_agent) {
			entity.setAgent(selection_agent.getSelection());
		} else if (eventSource == text) {
			entity.setText(text.getText());
		}
	}

}
