// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.section.supplemental;

import org.eclipse.swt.widgets.Label;
import org.joda.time.DateTime;

import eu.etaxonomy.cdm.common.CdmUtils;
import eu.etaxonomy.cdm.model.common.User;
import eu.etaxonomy.cdm.model.common.VersionableEntity;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.ui.forms.AbstractCdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.IEntityElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;

/**
 * <p>VersionElement class.</p>
 *
 * @author n.hoffmann
 * @created Nov 5, 2009
 * @version 1.0
 */
public class VersionElement extends AbstractCdmFormElement implements IEntityElement<VersionableEntity> {

	private Label label_created;
	private Label label_updated;
	
	private TextWithLabelElement text_uuid;
	private TextWithLabelElement text_objectId;
	private VersionableEntity entity;
	private boolean showDebug;
	
	/**
	 * <p>Constructor for VersionElement.</p>
	 *
	 * @param style a int.
	 * @param toolkit a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param entity a {@link eu.etaxonomy.cdm.model.common.VersionableEntity} object.
	 */
	public VersionElement(CdmFormFactory toolkit, ICdmFormElement parentElement, VersionableEntity entity, int style) {
		super(toolkit, parentElement);
		
		showDebug = PreferencesUtil.getPreferenceStore().getBoolean(PreferencesUtil.SHOW_DEBUG_INFORMATION);
				
		label_created = toolkit.createLabel(getLayoutComposite(), null);
		label_created.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY());

		label_updated = toolkit.createLabel(getLayoutComposite(), null);
		label_updated.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY());
		
		if(showDebug){
			text_uuid = toolkit.createTextWithLabelElement(parentElement, "UUID", null, style);
			
			text_objectId = toolkit.createTextWithLabelElement(parentElement, "Object ID", null, style);
		}
	}
	
	/**
	 * <p>Setter for the field <code>entity</code>.</p>
	 *
	 * @param entity a {@link eu.etaxonomy.cdm.model.common.VersionableEntity} object.
	 */
	public void setEntity(VersionableEntity entity){

		this.entity = entity;
		
		String createdString = "Created "
				+ dateFormat(entity.getCreated())
				+ " by " + userFormat(entity.getCreatedBy());			
		label_created.setText(createdString);

		String updatedString = "Updated "
				+ dateFormat(entity.getUpdated())
				+ " by " + userFormat(entity.getUpdatedBy());
		label_updated.setText(updatedString);
		
		
		
		if(showDebug){
			text_uuid.setText(entity.getUuid().toString());
			
			text_objectId.setText(entity.getId()+"");
		}
		
	}
	
	private String dateFormat(DateTime dateTime){
		if(dateTime == null){
			return "";
		}
		return CdmUtils.Nz(dateTime.toString(PreferencesUtil.getDateFormatPattern()));
	}
	
	private String userFormat(User user){
		if(user == null){
			return "";
		}
		// TODO agree on what to display username or real name or even more from shibboleth
		return CdmUtils.Nz(user.getUsername());
	}

	/**
	 * <p>Getter for the field <code>entity</code>.</p>
	 *
	 * @return a {@link eu.etaxonomy.cdm.model.common.VersionableEntity} object.
	 */
	public VersionableEntity getEntity() {
		return entity;
	}

	/** {@inheritDoc} */
	public void setSelected(boolean selected) {
		// will not likely be selected
	}
}
