// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.section.taxon;

import java.util.Arrays;

import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.swt.SWT;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.SelectionType;
import eu.etaxonomy.taxeditor.ui.forms.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.forms.CheckboxElement;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.TextWithLabelElement;
import eu.etaxonomy.taxeditor.ui.section.AbstractIdentifiableEntityDetailElement;
import eu.etaxonomy.taxeditor.ui.selection.ReferenceSelectionElement;

/**
 * <p>
 * TaxonBaseDetailElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Feb 26, 2010
 * @version 1.0
 */
public class TaxonBaseDetailElement extends AbstractIdentifiableEntityDetailElement<TaxonBase> {

	private CheckboxElement checkbox_doubtful;

	private CheckboxElement checkbox_useNameCache;

	private ReferenceSelectionElement selection_secundum;

	private TextWithLabelElement text_appendedPhrase;

	private CheckboxElement checkbox_excluded;

	private CheckboxElement checkbox_unplaced;

	/**
	 * <p>
	 * Constructor for TaxonBaseDetailElement.
	 * </p>
	 * 
	 * @param cdmFormFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param formElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement}
	 *            object.
	 * @param style
	 *            a int.
	 */
	public TaxonBaseDetailElement(CdmFormFactory cdmFormFactory,
			ICdmFormElement formElement, int style) {
		super(cdmFormFactory, formElement);
	}

	/** {@inheritDoc} */
	@Override
	protected void createControls(ICdmFormElement formElement,
			TaxonBase entity, int style) {
		toggleable_cache = formFactory.createToggleableTextField(formElement,
				"Title Cache", entity.getTitleCache(),
				entity.isProtectedTitleCache(), style);

		checkbox_doubtful = formFactory.createCheckbox(formElement,
				"Is doubtful", entity.isDoubtful(), style);
		checkbox_useNameCache = formFactory.createCheckbox(formElement,
				"Exclude Authorship", entity.isUseNameCache(), style);
		selection_secundum = (ReferenceSelectionElement) formFactory
				.createSelectionElement(SelectionType.REFERENCE,
						getConversationHolder(), formElement, "Secundum",
						entity.getSec(), ReferenceSelectionElement.DEFAULT,
						style);
		text_appendedPhrase = formFactory.createTextWithLabelElement(
				formElement, "Appended Phrase", entity.getAppendedPhrase(),
				SWT.NULL);

		if (entity instanceof Taxon) {
			checkbox_excluded = formFactory.createCheckbox(formElement,
					"Is excluded", ((Taxon) entity).isExcluded(), style);
			checkbox_unplaced = formFactory.createCheckbox(formElement,
					"Is unplaced", ((Taxon) entity).isUnplaced(), style);
		}
	}

	/** {@inheritDoc} */
	@Override
	protected void updateContent() {
		super.updateContent();
		toggleable_cache.setEnabled(getEntity().isProtectedTitleCache());
		setIrrelevant(toggleable_cache.getState(),
				Arrays.asList(new Object[] { toggleable_cache }));
	}
	
	@Override
	protected void handleTitleCacheRelevantChange(PropertyChangeEvent event) {
		String title = getEntity().generateTitle();
		getEntity().setTitleCache(title);
		super.handleTitleCacheRelevantChange(event);
	}

	/** {@inheritDoc} */
	@Override
	public void handleEvent(Object eventSource) {
		if (eventSource.equals(toggleable_cache)) {
			handleToggleableCacheField();
		} else if (eventSource.equals(checkbox_doubtful)) {
			getEntity().setDoubtful(checkbox_doubtful.getSelection());
		} else if (eventSource.equals(checkbox_useNameCache)) {
			getEntity().setUseNameCache(checkbox_useNameCache.getSelection());
		} else if (eventSource.equals(selection_secundum)) {
			getEntity().setSec(selection_secundum.getSelection());
		} else if (eventSource.equals(text_appendedPhrase)) {
			getEntity().setAppendedPhrase(text_appendedPhrase.getText());
		} else if (eventSource == checkbox_excluded) {
			((Taxon) getEntity()).setExcluded(checkbox_excluded.getSelection());
		} else if (eventSource == checkbox_unplaced) {
			((Taxon) getEntity()).setUnplaced(checkbox_unplaced.getSelection());
		}
	}
}
