// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.ui.selection;

import org.eclipse.swt.events.SelectionEvent;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.common.CdmUtils;
import eu.etaxonomy.cdm.model.taxon.Classification;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.ui.dialogs.filteredSelection.TaxonNodeSelectionDialog;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;

/**
 * <p>
 * TaxonNodeSelectionElement class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Sep 27, 2010
 * @version 1.0
 */
public class TaxonNodeSelectionElement extends
		AbstractSelectionElement<TaxonNode> {

	public static final int DEFAULT = DELETABLE;
	private Classification classification;

	/**
	 * <p>
	 * Constructor for TaxonNodeSelectionElement.
	 * </p>
	 * 
	 * @param formFactory
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory}
	 *            object.
	 * @param conversation
	 *            a {@link eu.etaxonomy.cdm.api.conversation.ConversationHolder}
	 *            object.
	 * @param parentElement
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement}
	 *            object.
	 * @param labelString
	 *            a {@link java.lang.String} object.
	 * @param entity
	 *            a {@link eu.etaxonomy.cdm.model.taxon.TaxonNode} object.
	 * @param style
	 *            a int.
	 */
	public TaxonNodeSelectionElement(CdmFormFactory formFactory,
			ConversationHolder conversation, ICdmFormElement parentElement,
			String labelString, TaxonNode entity, int mode, int style) {
		super(formFactory, conversation, parentElement, labelString, entity,
				mode, style);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt
	 * .events.SelectionEvent)
	 */
	/** {@inheritDoc} */
	@Override
	public void widgetSelected(SelectionEvent e) {
		TaxonNode newSelection = TaxonNodeSelectionDialog.select(getShell(),
				getConversationHolder(), "Select parent taxon", null, null, getClassification());
		setSelectionInternal(newSelection);
	}

	/**
	 * @return
	 */
	public Classification getClassification() {
		return classification;
	}
	
	public void setClassification(Classification classification){
		this.classification = classification;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.forms.selection.AbstractSelectionElement#getTitle
	 * ()
	 */
	/** {@inheritDoc} */
	@Override
	protected String getTitle() {
		if (getEntity() != null && getEntity().getTaxon() != null) {
			return CdmUtils.Nz(getEntity().getTaxon().getTitleCache());
		}
		return super.getTitle();
	}
}
