// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.term;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Label;

import eu.etaxonomy.taxeditor.preference.Resources;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.AbstractCdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmPropertyChangeEvent;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.IEnableableFormElement;

/**
 * <p>Abstract AbstractEnumComboElement class.</p>
 *
 * @author n.hoffmann
 * @created Mar 16, 2010
 * @version 1.0
 */
public abstract class AbstractEnumComboElement<T extends Enum> extends AbstractCdmFormElement implements SelectionListener, IEnableableFormElement{

	private static final int VISIBLE_ITEMS = 10;
	
	protected T selection;
	
	protected List<T> elementTypeList = new ArrayList<T>();
	
	private Label label;
	protected Combo combo;

	/**
	 * <p>Constructor for AbstractEnumComboElement.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param labelString a {@link java.lang.String} object.
	 * @param <T> a T object.
	 */
	public AbstractEnumComboElement(CdmFormFactory formFactory,
			ICdmFormElement parentElement, String labelString) {
		super(formFactory, parentElement);
		label = formFactory.createLabel(getLayoutComposite(), labelString);
		addControl(label);
		
		// create combo
	    combo = new Combo(getLayoutComposite(), SWT.BORDER | SWT.READ_ONLY);
		addControl(combo);
	    combo.setLayoutData(CdmFormFactory.FILL_HORIZONTALLY());
	    combo.setVisibleItemCount(VISIBLE_ITEMS);
	    
	    populateTypes();
	    
	    combo.addSelectionListener(this);
	}
	

	/**
	 * <p>populateTypes</p>
	 */
	protected abstract void populateTypes();
	
	
	/**
	 * <p>Setter for the field <code>selection</code>.</p>
	 *
	 * @param selection the selection to set
	 */
	public void setSelection(T selection) {
		this.selection = selection;
		combo.select(elementTypeList.indexOf(selection));
	}
	
	/**
	 * <p>addSelectionListener</p>
	 *
	 * @param listener a {@link org.eclipse.swt.events.SelectionListener} object.
	 */
	public void addSelectionListener(SelectionListener listener){
		combo.addSelectionListener(listener);
	}
	
	/**
	 * <p>removeSelectionListener</p>
	 *
	 * @param listener a {@link org.eclipse.swt.events.SelectionListener} object.
	 */
	public void removeSelectionListener(SelectionListener listener){
		combo.removeSelectionListener(listener);
	}

	/** {@inheritDoc} */
	public void setSelected(boolean selected) {
		label.setBackground(getColor(selected));
	}
	
	/**
	 * <p>Getter for the field <code>selection</code>.</p>
	 *
	 * @return the selection
	 */
	public T getSelection() {
		return selection;
	}

	/** {@inheritDoc} */
	public void setEnabled(boolean enabled) {
		combo.setEnabled(enabled);
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
	 */
	/** {@inheritDoc} */
	public void widgetSelected(SelectionEvent e) {
		selection = elementTypeList.get(combo.getSelectionIndex());
		firePropertyChangeEvent(new CdmPropertyChangeEvent(this, e));
	}
	
	/** {@inheritDoc} */
	public void setIrrelevant(boolean irrelevant) {
		String colorId = irrelevant ? Resources.COLOR_COMPOSITE_IRRELEVANT : Resources.COLOR_COMPOSITE_BACKGROUND;
		
		Color color = StoreUtil.getColor(colorId);
		combo.setBackground(color);
	}
	
	/** {@inheritDoc} */
	@Override
	public void setBackground(Color color) {
		label.setBackground(color);
	}
	
	/** {@inheritDoc} */
	public void widgetDefaultSelected(SelectionEvent e) {}
}
