// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.term;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jface.util.PropertyChangeEvent;

import eu.etaxonomy.cdm.model.common.DefinedTermBase;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;

/**
 * <p>EmptyComboElement class.</p>
 *
 * @author n.hoffmann
 * @created Sep 29, 2010
 * @version 1.0
 */
public class EmptyComboElement<T extends DefinedTermBase> extends AbstractTermComboElement<T> {

	private static final int VISIBLE_ITEMS = 20;
	
	private List<T> genericTerms = new ArrayList<T>();
	
	/**
	 * <p>Constructor for EmptyComboElement.</p>
	 *
	 * @param formFactory a {@link eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory} object.
	 * @param parentElement a {@link eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement} object.
	 * @param labelString a {@link java.lang.String} object.
	 * @param style a int.
	 * @param <T> a T object.
	 */
	public EmptyComboElement(CdmFormFactory formFactory,
			ICdmFormElement parentElement, String labelString,
			int style) {
		super(formFactory, parentElement, labelString, null, VISIBLE_ITEMS, style);
	}


	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.forms.term.AbstractTermComboElement#preferredTerms()
	 */
	/** {@inheritDoc} */
	@Override
	protected List<T> preferredTerms() {
		return genericTerms != null ? genericTerms : new ArrayList<T>();
	}


	/**
	 * <p>setTerms</p>
	 *
	 * @param terms a {@link java.util.List} object.
	 */
	public void setTerms(List<T> terms) {
		if(terms == null){
			throw new IllegalArgumentException("List of terms may not be null");
		}
		
		this.genericTerms = terms;
		propertyChange(new PropertyChangeEvent(this, PreferencesUtil.PREFERRED_TERMS_CHANGE, this.genericTerms, terms));
	}	
}
