// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.ui.translation;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.eclipse.core.runtime.Assert;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;

import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.common.LanguageString;
import eu.etaxonomy.cdm.model.common.MultilanguageTextHelper;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.TermComboType;
import eu.etaxonomy.taxeditor.ui.forms.ICdmFormElement;
import eu.etaxonomy.taxeditor.ui.forms.LanguageStringWithLabelElement;
import eu.etaxonomy.taxeditor.ui.forms.MultilanguageTextElement;
import eu.etaxonomy.taxeditor.ui.forms.RootElement;
import eu.etaxonomy.taxeditor.ui.term.EmptyComboElement;
import eu.etaxonomy.taxeditor.ui.term.LanguageComboElement;

/**
 * <p>TranslationWizardPage class.</p>
 *
 * @author n.hoffmann
 * @created Sep 29, 2010
 * @version 1.0
 */
public class TranslationWizardPage extends WizardPage{
		
	private static int TEXT_HEIGHT = 400;  
	
	private Map<Language, LanguageString> multilanguageText;

	MultilanguageTextElement source;
	
	private CdmFormFactory formFactory;

	private EmptyComboElement<Language> combo_sourceLanguage;

	private LanguageStringWithLabelElement text_source;

	private LanguageComboElement combo_targetLanguage;

	private LanguageStringWithLabelElement text_target;
	
	/**
	 * <p>Constructor for TranslationWizardPage.</p>
	 *
	 * @param multilanguageText a {@link java.util.Map} object.
	 */
	protected TranslationWizardPage(Map<Language, LanguageString> multilanguageText) {
		super("TranslationWizardPage");
		Assert.isNotNull(multilanguageText, "Multilanguage text may not be null");
		setTitle("Add or edit translations.");
		this.multilanguageText = multilanguageText;
		formFactory = new CdmFormFactory(Display.getCurrent());
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	public void createControl(Composite parent) {
		Composite control = formFactory.createComposite(parent);
//		control.setBackground(Display.getCurrent().getSystemColor(SWT.COLOR_GREEN));
		control.setLayout(CdmFormFactory.LAYOUT(2, true));
		
		Composite leftContainer = formFactory.createComposite(control);
		leftContainer.setLayoutData(CdmFormFactory.FILL());
		leftContainer.setLayout(CdmFormFactory.LAYOUT(1, false));
//		leftContainer.setBackground(Display.getCurrent().getSystemColor(SWT.COLOR_BLUE));
		RootElement leftRoot = new RootElement(formFactory, leftContainer);
		
		Composite rightContainer = formFactory.createComposite(control);
		rightContainer.setLayoutData(CdmFormFactory.FILL());
		rightContainer.setLayout(CdmFormFactory.LAYOUT(1, false));
//		rightContainer.setBackground(Display.getCurrent().getSystemColor(SWT.COLOR_RED));
		RootElement rightRoot = new RootElement(formFactory, rightContainer);
		
		createLeftControls(leftRoot);
		createRightControls(rightRoot);
		
		// initialize with default language
		setSource(CdmStore.getDefaultLanguage());
		
		
		setControl(control);
	}
	
	/**
	 * @param defaultLanguage
	 */
	private void setSource(Language language) {
		
		List<Language> languages = Arrays.asList(new Language[]{language});
		
		LanguageString preferredLanguageString = MultilanguageTextHelper.getPreferredLanguageString(multilanguageText, languages);
		
		if(preferredLanguageString != null){
			combo_sourceLanguage.setSelection(preferredLanguageString.getLanguage());
			text_source.setLanguageString(preferredLanguageString);
		}
	}


	/**
	 * 
	 * @param element
	 */
	private void createLeftControls(ICdmFormElement element){
		
		combo_sourceLanguage = (EmptyComboElement<Language>) formFactory.createTermComboElement(TermComboType.EMPTY, element, null, null, SWT.NULL);
		combo_sourceLanguage.setTerms(getLanguages());
		
		combo_sourceLanguage.addSelectionListener(new SelectionAdapter() {
			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.SelectionAdapter#widgetSelected(org.eclipse.swt.events.SelectionEvent)
			 */
			@Override
			public void widgetSelected(SelectionEvent e) {
				text_source.setLanguageString(multilanguageText.get(combo_sourceLanguage.getSelection()));
			}
		});
		
		LanguageString preferredLanguageString = MultilanguageTextHelper.getPreferredLanguageString(multilanguageText, getLanguages());
		
		text_source = formFactory.createLanguageStringWithLabelElement(element, null, preferredLanguageString, TEXT_HEIGHT, SWT.NULL);

//		text_source.setEnabled(false);
		
		text_source.setText(preferredLanguageString.getText());
	}
		
	/**
	 * 
	 * @param element
	 */
	private void createRightControls(ICdmFormElement element){
		combo_targetLanguage = (LanguageComboElement) formFactory.createTermComboElement(TermComboType.LANGUAGE, element, null, null, SWT.NULL);
		
		combo_targetLanguage.addSelectionListener(new SelectionAdapter() {
			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.SelectionAdapter#widgetSelected(org.eclipse.swt.events.SelectionEvent)
			 */
			@Override
			public void widgetSelected(SelectionEvent e) {
				Language language = combo_targetLanguage.getSelection();
				LanguageString languageString;
				
				if(multilanguageText.containsKey(language)){
					languageString = multilanguageText.get(language);
				}else{
					languageString = LanguageString.NewInstance("", language);
					multilanguageText.put(language, languageString);
				}
				
				text_target.setLanguageString(languageString);
			}
		});
		
		text_target = formFactory.createLanguageStringWithLabelElement(element, null, null, TEXT_HEIGHT, SWT.NULL);
		
		Button button_translationService = formFactory.createButton(element.getLayoutComposite(), "Translate", SWT.PUSH);
		button_translationService.addSelectionListener(new SelectionAdapter() {
			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.SelectionAdapter#widgetSelected(org.eclipse.swt.events.SelectionEvent)
			 */
			@Override
			public void widgetSelected(SelectionEvent event) {
				ITranslationServiceWrapper service = new GoogleLanguageApiWrapper();
				String translatedText;
				try {
					String text = text_source.getText();
					Language sourceLanguage = text_source.getLanguageString().getLanguage();
					Language targetLanguage = combo_targetLanguage.getSelection();
					
					translatedText = service.translate(text, sourceLanguage, targetLanguage);
					text_target.setText(translatedText);
				} catch (LanguageNotSupportedException e) {
					StoreUtil.warningDialog("Language not supported", TranslationWizardPage.class, e.getMessage());
				} catch (Exception e){
					StoreUtil.warningDialog("Error translating text", TranslationWizardPage.class, e.getMessage());
				}
				
			}
		});
	}

	
	/**
	 * 
	 * @return
	 */
	private List<Language> getLanguages(){
		Set<Language> languageSet = MultilanguageTextHelper.getLanguages(multilanguageText);
		
		List<Language> languageList = new ArrayList<Language>(languageSet);
				
		return languageList;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.DialogPage#dispose()
	 */
	/** {@inheritDoc} */
	@Override
	public void dispose() {
		super.dispose();
	}
}
