// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.view.datasource.handler;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.taxeditor.datasource.CdmDataSourceRepository;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.view.datasource.CdmMetaDataAwareDataSourceContainer;

/**
 * <p>ChangeConnectionHandler class.</p>
 *
 * @author n.hoffmann
 * @created 15.04.2009
 * @version 1.0
 */
public class ChangeConnectionHandler extends AbstractHandler {

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.store.datasource.handler.AbstractDataSourceHandler#specificExecute(org.eclipse.core.commands.ExecutionEvent)
	 */
	/** {@inheritDoc} */
	public Object execute(ExecutionEvent event) {
		ISelection selection = HandlerUtil.getCurrentSelection(event);
		
		if(selection != null && selection instanceof IStructuredSelection){
			CdmMetaDataAwareDataSourceContainer container = (CdmMetaDataAwareDataSourceContainer) ((IStructuredSelection) selection).getFirstElement();
			
			if(CdmStore.isConnecting()){
				StoreUtil.warningDialog("Already connecting", this, "You are currently connecting to a different datasource already.");
				return null;
			}
			
			if(!container.isRunning()){
				StoreUtil.warningDialog("Chosen datasource is not available", this, "This could mean that either the database server is " +
						"not running or the machine is not reachable.\n\n" +
						"Please also make sure that you are connected to the network when trying to connect to a remote datasource.");
				return null;
			}
			
			boolean confirmed = StoreUtil.confirmDialog("Confirm Datasource Connection", "Do you really want to connect to this datasource?\n\n"
					+ container.getDataSource().getName());
			
			if(confirmed){
				CdmDataSourceRepository.changeDataSource(container.getDataSource());
			}
		}
		
		return null;
	}
}
