// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.view.detail;

import org.eclipse.jface.util.IPropertyChangeListener;
import org.eclipse.jface.util.PropertyChangeEvent;
import org.eclipse.ui.forms.SectionPart;

import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.cdm.api.facade.DerivedUnitFacadeNotSupportedException;
import eu.etaxonomy.cdm.model.occurrence.DerivedUnitBase;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.model.IElementHasDetails;
import eu.etaxonomy.taxeditor.model.PolytomousKeyRelationship;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection;
import eu.etaxonomy.taxeditor.ui.section.AbstractCdmDetailElement;
import eu.etaxonomy.taxeditor.ui.section.ITaxonBaseDetailSection;
import eu.etaxonomy.taxeditor.ui.section.occurrence.IDerivedUnitFacadeDetailSection;

/**
 * <p>
 * CdmSectionPart class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Feb 8, 2010
 * @version 1.0
 */
public class CdmSectionPart<T> extends SectionPart implements
		IPropertyChangeListener {

	private final AbstractFormSection<T> formSection;

	/**
	 * <p>
	 * Constructor for CdmSectionPart.
	 * </p>
	 * 
	 * @param section
	 *            a {@link eu.etaxonomy.taxeditor.ui.forms.AbstractFormSection}
	 *            object.
	 * @param <T>
	 *            a T object.
	 */
	public CdmSectionPart(AbstractFormSection<T> section) {
		super(section);
		formSection = section;
	}

	/** {@inheritDoc} */
	@Override
	public boolean setFormInput(Object input) {
		if (input instanceof IElementHasDetails) {
			input = ((IElementHasDetails) input).getData();
		}
		if ((input instanceof TaxonBase)
				&& (formSection instanceof ITaxonBaseDetailSection)) {
			((ITaxonBaseDetailSection) formSection)
					.setTaxonBase((TaxonBase) input);
			return true;
		}
		if ((input instanceof DerivedUnitBase)
				&& (formSection instanceof IDerivedUnitFacadeDetailSection)) {

			try {
				input = DerivedUnitFacade.NewInstance((DerivedUnitBase) input,
						PreferencesUtil.getDerivedUnitConfigurator());
			} catch (DerivedUnitFacadeNotSupportedException e) {
				StoreUtil.error(getClass(), e);
			}
		}
		if (input instanceof PolytomousKeyRelationship) {
			input = ((PolytomousKeyRelationship) input).getDestination();
		}

		formSection.setEntity((T) input);

		return true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.jface.util.IPropertyChangeListener#propertyChange(org.eclipse
	 * .jface.util.PropertyChangeEvent)
	 */
	/** {@inheritDoc} */
	@Override
	public void propertyChange(PropertyChangeEvent event) {
		if (event != null) {

			Object eventSource = event.getSource();

			if (formSection.equals(eventSource)
					|| (eventSource instanceof AbstractCdmDetailElement && formSection
							.containsFormElement((AbstractCdmDetailElement) eventSource))) {
				markDirty();
			}
		}
	}

}
