// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.view.detail;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.forms.widgets.Section;

import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.cdm.api.facade.DerivedUnitFacadeNotSupportedException;
import eu.etaxonomy.cdm.model.agent.Person;
import eu.etaxonomy.cdm.model.agent.Team;
import eu.etaxonomy.cdm.model.agent.TeamOrPersonBase;
import eu.etaxonomy.cdm.model.common.Group;
import eu.etaxonomy.cdm.model.common.User;
import eu.etaxonomy.cdm.model.description.DescriptionBase;
import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.PolytomousKey;
import eu.etaxonomy.cdm.model.description.PolytomousKeyNode;
import eu.etaxonomy.cdm.model.media.Media;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.occurrence.DerivedUnitBase;
import eu.etaxonomy.cdm.model.reference.Reference;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.model.FeatureNodeContainer;
import eu.etaxonomy.taxeditor.model.PolytomousKeyRelationship;
import eu.etaxonomy.taxeditor.preference.IPreferenceKeys;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.DetailType;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.EntityDetailType;
import eu.etaxonomy.taxeditor.ui.forms.RootElement;
import eu.etaxonomy.taxeditor.ui.section.agent.PersonDetailSection;
import eu.etaxonomy.taxeditor.ui.section.agent.TeamDetailSection;
import eu.etaxonomy.taxeditor.ui.section.agent.TeamOrPersonBaseDetailSection;
import eu.etaxonomy.taxeditor.ui.section.description.DescribedSpecimenSection;
import eu.etaxonomy.taxeditor.ui.section.description.DescriptionDetailSection;
import eu.etaxonomy.taxeditor.ui.section.description.DescriptionElementDetailSection;
import eu.etaxonomy.taxeditor.ui.section.description.DescriptionElementMediaSection;
import eu.etaxonomy.taxeditor.ui.section.description.DescriptionElementSourceSection;
import eu.etaxonomy.taxeditor.ui.section.description.DescriptionSourceSection;
import eu.etaxonomy.taxeditor.ui.section.description.MediaDetailsSection;
import eu.etaxonomy.taxeditor.ui.section.description.NaturalLanguageSection;
import eu.etaxonomy.taxeditor.ui.section.description.ScopeSection;
import eu.etaxonomy.taxeditor.ui.section.feature.FeatureDistributionDetailSection;
import eu.etaxonomy.taxeditor.ui.section.group.GrantedAuthorityDetailSection;
import eu.etaxonomy.taxeditor.ui.section.group.GroupDetailSection;
import eu.etaxonomy.taxeditor.ui.section.group.MemberDetailSection;
import eu.etaxonomy.taxeditor.ui.section.key.GeographicalScopeDetailSection;
import eu.etaxonomy.taxeditor.ui.section.key.PolytomousKeyDetailSection;
import eu.etaxonomy.taxeditor.ui.section.key.PolytomousKeyNodeDetailSection;
import eu.etaxonomy.taxeditor.ui.section.key.ScopeRestrictionSection;
import eu.etaxonomy.taxeditor.ui.section.key.TaxonomicScopeSection;
import eu.etaxonomy.taxeditor.ui.section.name.HybridDetailSection;
import eu.etaxonomy.taxeditor.ui.section.name.NameRelationshipDetailSection;
import eu.etaxonomy.taxeditor.ui.section.name.NomenclaturalStatusSection;
import eu.etaxonomy.taxeditor.ui.section.name.NonViralNameDetailSection;
import eu.etaxonomy.taxeditor.ui.section.name.ProtologueSection;
import eu.etaxonomy.taxeditor.ui.section.name.TypeDesignationSection;
import eu.etaxonomy.taxeditor.ui.section.occurrence.DerivedUnitBaseDetailSection;
import eu.etaxonomy.taxeditor.ui.section.occurrence.DeterminationDetailSection;
import eu.etaxonomy.taxeditor.ui.section.occurrence.FieldObservationDetailSection;
import eu.etaxonomy.taxeditor.ui.section.occurrence.GatheringEventDetailSection;
import eu.etaxonomy.taxeditor.ui.section.occurrence.GeneralDetailSection;
import eu.etaxonomy.taxeditor.ui.section.reference.NomenclaturalReferenceDetailSection;
import eu.etaxonomy.taxeditor.ui.section.reference.ReferenceDetailSection;
import eu.etaxonomy.taxeditor.ui.section.taxon.ParsingMessagesSection;
import eu.etaxonomy.taxeditor.ui.section.taxon.TaxonBaseDetailSection;
import eu.etaxonomy.taxeditor.ui.section.user.GroupsByUserDetailSection;
import eu.etaxonomy.taxeditor.ui.section.user.UserDetailSection;
import eu.etaxonomy.taxeditor.view.AbstractCdmDataViewer;
import eu.etaxonomy.taxeditor.view.AbstractCdmViewPart;

/**
 * <p>
 * DetailsViewer class.
 * </p>
 * 
 * @author n.hoffmann
 * @created Feb 12, 2010
 * @version 1.0
 */
public class DetailsViewer extends AbstractCdmDataViewer {

	private enum VIEW_PART {
		TAXON, NAME, REFEERENCE, TEAM, PERSON, DESCRIPTION, DESCRIPTION_ELEMENT, EMPTY, IMAGE_GALLERY, MEDIA, TEAM_OR_PERSON_BASE, DERIVED_UNIT, FEATURE_DISTRIBUTION, POLYTOMOUS_KEY, POLYTOMOUS_KEY_NODE, USER, GROUP
	}

	private VIEW_PART currentViewPart;

	private ISelection selection;

	/**
	 * <p>
	 * Constructor for DetailsViewer.
	 * </p>
	 * 
	 * @param parent
	 *            a {@link org.eclipse.swt.widgets.Composite} object.
	 * @param viewPart
	 *            a {@link eu.etaxonomy.taxeditor.view.AbstractCdmViewPart}
	 *            object.
	 */
	public DetailsViewer(Composite parent, AbstractCdmViewPart viewPart) {
		super(parent, viewPart);
	}

	// START HACK TO MAKE THE DERIVED UNIT FACADE WORK
	// since we are getting implementations of DerivedUnitBase from the bulk
	// editor
	// and not derived unit facade objects,

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * eu.etaxonomy.taxeditor.editor.view.AbstractCdmDataViewer#setInput(java
	 * .lang.Object)
	 */
	@Override
	public void setInput(Object input) {
		if (input instanceof DerivedUnitBase) {
			try {
				input = DerivedUnitFacade.NewInstance((DerivedUnitBase) input,
						PreferencesUtil.getDerivedUnitConfigurator());
			} catch (DerivedUnitFacadeNotSupportedException e) {
				StoreUtil.error(getClass(), e);
			}
		}
		super.setInput(input);
	}

	@Override
	protected void markViewPartDirty() {
		if (getInput() instanceof DerivedUnitFacade) {
			getViewPart().changed(
					((DerivedUnitFacade) getInput()).innerDerivedUnit());
		}

		super.markViewPartDirty();
	}

	// END HACK TO MAKE THE DERIVED UNIT FACADE WORK

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.jface.viewers.Viewer#refresh()
	 */
	/** {@inheritDoc} */
	@Override
	protected void showParts() {
		if (getInput() instanceof TaxonBase) {
			if (currentViewPart != VIEW_PART.TAXON) {
				createTaxonSections(rootElement);
				currentViewPart = VIEW_PART.TAXON;

				// preserve a pointer to the AbstractNameComposite
				// MultiPageTaxonEditor editor =
				// EditorUtil.getActiveMultiPageTaxonEditor();
				// if(editor != null){
				// TaxonNameEditor page = (TaxonNameEditor)
				// editor.getPage(Page.NAME);
				// for(AbstractGroupedContainer container :
				// page.getGroupedContainers()){
				// if(container.getData() == getInput()){
				// sourceContainer = container;
				// }
				// }
				// }
			}
		} else if (getInput() instanceof NonViralName) {
			if (currentViewPart != VIEW_PART.NAME) {
				createNameSections(rootElement);
				currentViewPart = VIEW_PART.NAME;
			}
		} else if (getInput() instanceof Reference) {
			if (currentViewPart != VIEW_PART.REFEERENCE) {
				createReferenceSections(rootElement);
				currentViewPart = VIEW_PART.REFEERENCE;
			}
		} else if (getInput() instanceof Team) {
			if (currentViewPart != VIEW_PART.TEAM) {
				createTeamDetailSection(rootElement);
				currentViewPart = VIEW_PART.TEAM;
			}
		} else if (getInput() instanceof Person) {
			if (currentViewPart != VIEW_PART.PERSON) {
				createPersonDetailSection(rootElement);
				currentViewPart = VIEW_PART.PERSON;
			}
		} else if (getInput() instanceof TeamOrPersonBase) {
			// fallback
			if (currentViewPart != VIEW_PART.TEAM_OR_PERSON_BASE) {
				createTeamOrPersonBaseDetailSection(rootElement);
				currentViewPart = VIEW_PART.TEAM_OR_PERSON_BASE;
			}
		} else if (getInput() instanceof DescriptionBase) {
			if (((DescriptionBase) getInput()).isImageGallery()) {
				if (currentViewPart != VIEW_PART.IMAGE_GALLERY) {
					createImageGallerySection(rootElement);
					currentViewPart = VIEW_PART.IMAGE_GALLERY;
				}
			} else {
				if (currentViewPart != VIEW_PART.DESCRIPTION) {
					createDescriptionSection(rootElement);
					currentViewPart = VIEW_PART.DESCRIPTION;
				}
			}
		} else if (getInput() instanceof DescriptionElementBase) {
			if (currentViewPart != VIEW_PART.DESCRIPTION_ELEMENT) {
				createDescriptionElementSection(rootElement);
				currentViewPart = VIEW_PART.DESCRIPTION_ELEMENT;
			}
		} else if (getInput() instanceof Media) {
			if (currentViewPart != VIEW_PART.MEDIA) {
				createMediaElementSection(rootElement);
				currentViewPart = VIEW_PART.MEDIA;
			}
		} else if (getInput() instanceof DerivedUnitFacade) {
			if (currentViewPart != VIEW_PART.DERIVED_UNIT) {
				createDerivedUnitBaseElementSection(rootElement);
				currentViewPart = VIEW_PART.DERIVED_UNIT;
			}
		} else if (getInput() instanceof FeatureNodeContainer) {
			if (currentViewPart != VIEW_PART.FEATURE_DISTRIBUTION) {
				createFeatureDistributionSection(rootElement);
				currentViewPart = VIEW_PART.FEATURE_DISTRIBUTION;
			}
		} else if (getInput() instanceof PolytomousKey) {
			if (currentViewPart != VIEW_PART.POLYTOMOUS_KEY) {
				createPolytomousKeySection(rootElement);
				currentViewPart = VIEW_PART.POLYTOMOUS_KEY;
			}
		} else if ((getInput() instanceof PolytomousKeyNode)
				|| (getInput() instanceof PolytomousKeyRelationship)) {
			if (currentViewPart != VIEW_PART.POLYTOMOUS_KEY_NODE) {
				createPolytomousKeyNodeSection(rootElement);
				currentViewPart = VIEW_PART.POLYTOMOUS_KEY_NODE;
			}
		} else if (getInput() instanceof User) {
			if (currentViewPart != VIEW_PART.USER) {
				createUserSection(rootElement);
				currentViewPart = VIEW_PART.USER;
			}
		} else if (getInput() instanceof Group) {
			if (currentViewPart != VIEW_PART.GROUP) {
				createGroupSection(rootElement);
				currentViewPart = VIEW_PART.GROUP;
			}
		} else {
			destroySections();
			currentViewPart = VIEW_PART.EMPTY;
		}

		layout();
	}

	/**
	 * @param rootElement
	 */
	private void createGroupSection(RootElement parent) {
		destroySections();

		GroupDetailSection groupDetailSection = (GroupDetailSection) formFactory
				.createCdmDetailSection(DetailType.GROUP,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);
		MemberDetailSection memberDetailSection = (MemberDetailSection) formFactory
				.createEntityDetailSection(EntityDetailType.MEMBER,
						getConversationHolder(), parent, Section.TWISTIE
								| Section.EXPANDED);
		GrantedAuthorityDetailSection grantedAuthorityDetailSection = (GrantedAuthorityDetailSection) formFactory
				.createEntityDetailSection(EntityDetailType.GRANTED_AUTHORITY,
						getConversationHolder(), parent, Section.TWISTIE
								| Section.EXPANDED);

		addPart(groupDetailSection);
		addPart(memberDetailSection);
		addPart(grantedAuthorityDetailSection);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.eclipse.jface.viewers.Viewer#getSelection()
	 */
	/** {@inheritDoc} */
	@Override
	public ISelection getSelection() {
		return selection;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.jface.viewers.Viewer#setSelection(org.eclipse.jface.viewers
	 * .ISelection, boolean)
	 */
	/** {@inheritDoc} */
	@Override
	public void setSelection(ISelection selection, boolean reveal) {
		this.selection = selection;
		SelectionChangedEvent selectionChangedEvent = new SelectionChangedEvent(
				this, selection);
		fireSelectionChanged(selectionChangedEvent);
	}

	private void createTaxonSections(RootElement parent) {
		destroySections();

		TaxonBaseDetailSection taxonBaseDetailSection = (TaxonBaseDetailSection) formFactory
				.createCdmDetailSection(DetailType.TAXONBASE,
						getConversationHolder(), parent, this, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		NonViralNameDetailSection nonViralNameSection = (NonViralNameDetailSection) formFactory
				.createCdmDetailSection(DetailType.NONVIRALNAME,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		NomenclaturalReferenceDetailSection referenceDetailSection = (NomenclaturalReferenceDetailSection) formFactory
				.createCdmDetailSection(DetailType.NOMENCLATURALREFERENCE,
						getConversationHolder(), parent, this, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		NomenclaturalStatusSection nomenclaturalStatusSection = (NomenclaturalStatusSection) formFactory
				.createEntityDetailSection(
						EntityDetailType.NOMENCLATURALSTATUS,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		ProtologueSection protologSection = (ProtologueSection) formFactory
				.createEntityDetailSection(EntityDetailType.PROTOLOG,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		TypeDesignationSection typeDesignationSection = (TypeDesignationSection) formFactory
				.createEntityDetailSection(EntityDetailType.TYPEDESIGNATION,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		NameRelationshipDetailSection nameRelationshipSection = (NameRelationshipDetailSection) formFactory
				.createEntityDetailSection(EntityDetailType.NAME_RELATIONSHIP,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		ParsingMessagesSection parsingMessagesSection = (ParsingMessagesSection) formFactory
				.createCdmDetailSection(DetailType.PARSINGMESSAGE,
						getConversationHolder(), parent, this, Section.EXPANDED);

		addPart(taxonBaseDetailSection);
		addPart(nonViralNameSection);
		addPart(nomenclaturalStatusSection);
		addPart(protologSection);
		addPart(referenceDetailSection);
		addPart(typeDesignationSection);
		addPart(nameRelationshipSection);
		addPart(parsingMessagesSection);
	}

	private void createNameSections(RootElement parent) {
		destroySections();
		NonViralNameDetailSection nonViralNameSection = (NonViralNameDetailSection) formFactory
				.createCdmDetailSection(DetailType.NONVIRALNAME,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		NomenclaturalReferenceDetailSection referenceDetailSection = (NomenclaturalReferenceDetailSection) formFactory
				.createCdmDetailSection(DetailType.NOMENCLATURALREFERENCE,
						getConversationHolder(), parent, this, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		NomenclaturalStatusSection nomenclaturalStatusSection = (NomenclaturalStatusSection) formFactory
				.createEntityDetailSection(
						EntityDetailType.NOMENCLATURALSTATUS,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		ProtologueSection protologSection = (ProtologueSection) formFactory
				.createEntityDetailSection(EntityDetailType.PROTOLOG,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		TypeDesignationSection typeDesignationSection = (TypeDesignationSection) formFactory
				.createEntityDetailSection(EntityDetailType.TYPEDESIGNATION,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		NameRelationshipDetailSection nameRelationshipSection = (NameRelationshipDetailSection) formFactory
				.createEntityDetailSection(EntityDetailType.NAME_RELATIONSHIP,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		addPart(nonViralNameSection);
		addPart(nomenclaturalStatusSection);
		addPart(protologSection);
		addPart(referenceDetailSection);
		addPart(typeDesignationSection);
		addPart(nameRelationshipSection);
	}

	private void createReferenceSections(RootElement parent) {
		destroySections();

		ReferenceDetailSection referenceDetailSection = (ReferenceDetailSection) formFactory
				.createCdmDetailSection(DetailType.REFERENCEBASE,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		addPart(referenceDetailSection);
	}

	private void createTeamOrPersonBaseDetailSection(RootElement parent) {
		destroySections();
		TeamOrPersonBaseDetailSection teamOrPersonBaseDetailSection = (TeamOrPersonBaseDetailSection) formFactory
				.createCdmDetailSection(DetailType.TEAMORPERSONBASE,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		addPart(teamOrPersonBaseDetailSection);
	}

	private void createTeamDetailSection(RootElement parent) {
		destroySections();
		TeamDetailSection teamDetailSection = (TeamDetailSection) formFactory
				.createCdmDetailSection(DetailType.TEAM,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		addPart(teamDetailSection);
	}

	private void createPersonDetailSection(RootElement parent) {
		destroySections();
		PersonDetailSection personDetailSection = (PersonDetailSection) formFactory
				.createCdmDetailSection(DetailType.PERSON,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);
		addPart(personDetailSection);
	}

	private void createDescriptionElementSection(RootElement parent) {
		destroySections();

		DescriptionElementDetailSection descriptionElementDetailSection = (DescriptionElementDetailSection) formFactory
				.createCdmDetailSection(DetailType.DESCRIPTIONELEMENT,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		DescriptionElementSourceSection descriptionElementSourceSection = (DescriptionElementSourceSection) formFactory
				.createEntityDetailSection(
						EntityDetailType.DESCRIPTIONELEMENTSOURCE,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		DescriptionElementMediaSection descriptionElementMediaSection = (DescriptionElementMediaSection) formFactory
				.createEntityDetailSection(
						EntityDetailType.DESCRIPTIONELEMENTMEDIA,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		addPart(descriptionElementDetailSection);
		addPart(descriptionElementSourceSection);
		addPart(descriptionElementMediaSection);
	}

	private void createDescriptionSection(RootElement parent) {
		destroySections();
		DescriptionDetailSection descriptionDetailSection = (DescriptionDetailSection) formFactory
				.createCdmDetailSection(DetailType.DESCRIPTION,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		NaturalLanguageSection naturalLanguageSection = (NaturalLanguageSection) formFactory
				.createCdmDetailSection(DetailType.NATURAL_LANGUAGE,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		DescribedSpecimenSection describedSpecimenSection = (DescribedSpecimenSection) formFactory
				.createEntityDetailSection(EntityDetailType.DESCRIBED_SPECIMEN,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		DescriptionSourceSection descriptionSourceSection = (DescriptionSourceSection) formFactory
				.createEntityDetailSection(EntityDetailType.DESCRIPTIONSOURCE,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		ScopeSection scopeSection = (ScopeSection) formFactory
				.createEntityDetailSection(EntityDetailType.SCOPE,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		addPart(descriptionDetailSection);
		addPart(naturalLanguageSection);
		addPart(describedSpecimenSection);
		addPart(descriptionSourceSection);
		addPart(scopeSection);
	}

	/**
	 * @param rootElement
	 */
	private void createImageGallerySection(RootElement parent) {
		destroySections();
		DescriptionDetailSection descriptionDetailSection = (DescriptionDetailSection) formFactory
				.createCdmDetailSection(DetailType.DESCRIPTION,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		addPart(descriptionDetailSection);
	}

	private void createMediaElementSection(RootElement parent) {
		destroySections();
		MediaDetailsSection mediaDetailSection = (MediaDetailsSection) formFactory
				.createCdmDetailSection(DetailType.MEDIA,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		addPart(mediaDetailSection);
	}

	private void createDerivedUnitBaseElementSection(RootElement parent) {
		destroySections();

		GeneralDetailSection generalDetailSection = (GeneralDetailSection) formFactory
				.createCdmDetailSection(DetailType.DERIVED_UNIT_GENERAL,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		GatheringEventDetailSection gatheringEventDetailSection = (GatheringEventDetailSection) formFactory
				.createCdmDetailSection(DetailType.GATHERING_EVENT,
						getConversationHolder(), parent, this, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		FieldObservationDetailSection fieldObservationDetailSection = (FieldObservationDetailSection) formFactory
				.createCdmDetailSection(DetailType.FIELD_OBSERVATION,
						getConversationHolder(), parent, this, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		DerivedUnitBaseDetailSection derivedUnitBaseDetailSection = (DerivedUnitBaseDetailSection) formFactory
				.createCdmDetailSection(DetailType.DERIVED_UNIT,
						getConversationHolder(), parent, this, Section.TWISTIE);
		
		Object getBoolean;
		formFactory.createHorizontalSeparator(parent, SWT.BORDER);
		
		DeterminationDetailSection determinationDetailSection = (DeterminationDetailSection) formFactory
				.createCdmDetailSection(DetailType.DETERMINATION, 
						getConversationHolder(), parent, this, Section.TWISTIE);
		

		addPart(generalDetailSection);
		addPart(gatheringEventDetailSection);
		addPart(fieldObservationDetailSection);
		addPart(derivedUnitBaseDetailSection);
		addPart(determinationDetailSection);

	}

	/**
	 * @param rootElement
	 */
	private void createFeatureDistributionSection(RootElement parent) {
		destroySections();

		FeatureDistributionDetailSection featureDistributionSection = (FeatureDistributionDetailSection) formFactory
				.createCdmDetailSection(DetailType.FEATURE_DISTRIBUTION,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		addPart(featureDistributionSection);
	}

	private void createPolytomousKeySection(RootElement parent) {
		destroySections();

		PolytomousKeyDetailSection polytomousKeyDetailSection = (PolytomousKeyDetailSection) formFactory
				.createCdmDetailSection(DetailType.POLYTOMOUS_KEY,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		GeographicalScopeDetailSection geographicalScopeDetailSection = (GeographicalScopeDetailSection) formFactory
				.createEntityDetailSection(EntityDetailType.GEOGRAPHICAL_SCOPE,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		ScopeRestrictionSection scopeRestrictionSection = (ScopeRestrictionSection) formFactory
				.createEntityDetailSection(EntityDetailType.SCOPE_RESTRICTION,
						getConversationHolder(), parent, Section.TWISTIE);

		formFactory.createHorizontalSeparator(parent, SWT.BORDER);

		TaxonomicScopeSection taxonomicScopeSection = (TaxonomicScopeSection) formFactory
				.createEntityDetailSection(EntityDetailType.TAXONOMIC_SCOPE,
						getConversationHolder(), parent, Section.TWISTIE);

		addPart(polytomousKeyDetailSection);
		addPart(geographicalScopeDetailSection);
		addPart(scopeRestrictionSection);
		addPart(taxonomicScopeSection);
	}

	private void createPolytomousKeyNodeSection(RootElement parent) {
		destroySections();

		PolytomousKeyNodeDetailSection polytomousKeyNodeDetailSection = (PolytomousKeyNodeDetailSection) formFactory
				.createCdmDetailSection(DetailType.POLYTOMOUS_KEY_NODE,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		addPart(polytomousKeyNodeDetailSection);
	}

	private void createUserSection(RootElement parent) {
		destroySections();

		UserDetailSection userDetailSection = (UserDetailSection) formFactory
				.createCdmDetailSection(DetailType.USER,
						getConversationHolder(), parent, this, Section.TWISTIE
								| Section.EXPANDED);

		GroupsByUserDetailSection groupByUserDetailSection = (GroupsByUserDetailSection) formFactory
				.createEntityDetailSection(EntityDetailType.GROUPS_BY_USER,
						getConversationHolder(), parent, Section.TWISTIE
								| Section.EXPANDED);

		addPart(userDetailSection);
		addPart(groupByUserDetailSection);
	}
}
