// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.view.supplementaldata;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.part.EditorPart;

import eu.etaxonomy.cdm.api.facade.DerivedUnitFacade;
import eu.etaxonomy.taxeditor.model.FeatureNodeContainer;
import eu.etaxonomy.taxeditor.store.StoreUtil;
import eu.etaxonomy.taxeditor.view.AbstractCdmEditorViewPart;
import eu.etaxonomy.taxeditor.view.AbstractCdmViewPart;


/**
 * <p>SupplementalDataViewPart class.</p>
 *
 * @author n.hoffmann
 * @created Jun 10, 2010
 * @version 1.0
 */
public class SupplementalDataViewPart extends AbstractCdmEditorViewPart {

	/** Constant <code>ID="eu.etaxonomy.taxeditor.editor.view.supp"{trunked}</code> */
	public static final String ID = "eu.etaxonomy.taxeditor.view.supplementalData";

	private SupplementalDataViewer viewer;
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.WorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	public void createViewer(Composite parent) {
		viewer = new SupplementalDataViewer(parent, this);
	}


	/** {@inheritDoc} */
	public void selectionChanged(IWorkbenchPart part, ISelection selection) {
		if(StoreUtil.getActiveEditor() == null){
			showEmptyPage();
			return;
		}
		
		if(((part instanceof EditorPart) || (part instanceof AbstractCdmViewPart)) && selection instanceof IStructuredSelection) {
			IStructuredSelection structuredSelection = (IStructuredSelection) selection;
			if(structuredSelection.size() != 1){
				showEmptyPage();
				return;
			}
			
			// do not show supplemental data for feature nodes
			if(structuredSelection.getFirstElement() instanceof FeatureNodeContainer){
				showEmptyPage();
				return;
			}
			if(structuredSelection.getFirstElement() instanceof DerivedUnitFacade){
				return;
			}
			
			showViewer(part, structuredSelection);
		}else{
			showEmptyPage();		
		}
	}
	
	/** {@inheritDoc} */
	@Override
	public void dispose() {
		super.dispose();
		selectionService.removePostSelectionListener(this);
	}


	/** {@inheritDoc} */
	@Override
	public Viewer getViewer() {
		return viewer;
	}

	/**
	 * <p>onComplete</p>
	 *
	 * @return a boolean.
	 */
	public boolean onComplete() {
		// TODO Auto-generated method stub
		return false;
	}
	
	
}
