// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.view.supplementaldata;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.forms.widgets.Section;

import eu.etaxonomy.cdm.model.common.AnnotatableEntity;
import eu.etaxonomy.cdm.model.common.IdentifiableEntity;
import eu.etaxonomy.cdm.model.common.VersionableEntity;
import eu.etaxonomy.cdm.model.media.IdentifiableMediaEntity;
import eu.etaxonomy.taxeditor.model.IElementHasDetails;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory;
import eu.etaxonomy.taxeditor.ui.forms.RootElement;
import eu.etaxonomy.taxeditor.ui.forms.CdmFormFactory.EntityDetailType;
import eu.etaxonomy.taxeditor.ui.section.media.MediaSection;
import eu.etaxonomy.taxeditor.ui.section.supplemental.AnnotationSection;
import eu.etaxonomy.taxeditor.ui.section.supplemental.CreditSection;
import eu.etaxonomy.taxeditor.ui.section.supplemental.ExtensionSection;
import eu.etaxonomy.taxeditor.ui.section.supplemental.HeadlineSection;
import eu.etaxonomy.taxeditor.ui.section.supplemental.MarkerSection;
import eu.etaxonomy.taxeditor.ui.section.supplemental.RightsSection;
import eu.etaxonomy.taxeditor.ui.section.supplemental.SourceSection;
import eu.etaxonomy.taxeditor.ui.section.supplemental.VersionSection;
import eu.etaxonomy.taxeditor.view.AbstractCdmDataViewer;
import eu.etaxonomy.taxeditor.view.AbstractCdmViewPart;
import eu.etaxonomy.taxeditor.view.detail.DetailsViewer;

/**
 * <p>SupplementalDataViewer class.</p>
 *
 * @author n.hoffmann
 * @created Feb 12, 2010
 * @version 1.0
 */
public class SupplementalDataViewer extends AbstractCdmDataViewer implements ISelectionChangedListener {

	private enum VIEW_PART{
		VersionableEntity, 
		AnnotatableEntity, 
		IdentifiableEntity, 
		IdentifiableMediaEntity,
		EMPTY;
	}
	
	private VIEW_PART currentViewPart;

	
	/**
	 * <p>Constructor for SupplementalDataViewer.</p>
	 *
	 * @param parent a {@link org.eclipse.swt.widgets.Composite} object.
	 * @param viewPart a {@link eu.etaxonomy.taxeditor.view.AbstractCdmViewPart} object.
	 */
	public SupplementalDataViewer(Composite parent, AbstractCdmViewPart viewPart) {
		super(parent, viewPart);
	}


	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.Viewer#getSelection()
	 */
	/** {@inheritDoc} */
	@Override
	public ISelection getSelection() {
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.Viewer#setSelection(org.eclipse.jface.viewers.ISelection, boolean)
	 */
	/** {@inheritDoc} */
	@Override
	public void setSelection(ISelection selection, boolean reveal) {

	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.view.AbstractDetailsViewer#showParts(eu.etaxonomy.cdm.model.common.AnnotatableEntity)
	 */
	/** {@inheritDoc} */
	@Override
	protected void showParts() {
		
		Object input;
		
		if(getInput() instanceof IElementHasDetails){
			input = ((IElementHasDetails) getInput()).getData();
		}else{
			input = getInput();
		}
		
		if(input instanceof IdentifiableMediaEntity){
			if(currentViewPart != VIEW_PART.IdentifiableMediaEntity){
				currentViewPart = VIEW_PART.IdentifiableMediaEntity;
				createIdentifiableMediaSections(rootElement);
			}
		}else if(input instanceof IdentifiableEntity){
			if(currentViewPart != VIEW_PART.IdentifiableEntity){
				currentViewPart = VIEW_PART.IdentifiableEntity;
				createIdentifiableSections(rootElement);
			}
		}else if(input instanceof AnnotatableEntity){
			if(currentViewPart != VIEW_PART.AnnotatableEntity){
				currentViewPart = VIEW_PART.AnnotatableEntity;
				createAnnotationSections(rootElement);
			}
		}else if(input instanceof VersionableEntity){
			if(currentViewPart != VIEW_PART.VersionableEntity){
				currentViewPart = VIEW_PART.VersionableEntity;
				createHeadlineSection(rootElement);
			}
		}else{
			currentViewPart = VIEW_PART.EMPTY;
		}
		
		layout();
	}
	
	private void createHeadlineSection(RootElement parent){
		destroySections();
		HeadlineSection headlineSection = formFactory.createHeadlineSection(parent);
		addPart(headlineSection);
		
		if(currentViewPart == VIEW_PART.VersionableEntity){
			createVersionSection(parent);
		}
	}
	
	private void createAnnotationSections(RootElement parent){
		createHeadlineSection(parent);
		AnnotationSection annotationSection = (AnnotationSection) 
			formFactory.createEntityDetailSection(EntityDetailType.ANNOTATION, getConversationHolder(), parent, Section.TWISTIE);
		
		formFactory.createHorizontalSeparator(parent, SWT.BORDER);
		
		MarkerSection markerSection = (MarkerSection)
			formFactory.createEntityDetailSection(EntityDetailType.MARKER, getConversationHolder(), parent, Section.TWISTIE);
		
		formFactory.createHorizontalSeparator(parent, SWT.BORDER);
		
		addPart(annotationSection);
		addPart(markerSection);
		
		if(currentViewPart == VIEW_PART.AnnotatableEntity){
			createVersionSection(parent);
		}
	}

	private void createIdentifiableSections(RootElement parent){
		createAnnotationSections(parent);		
		CreditSection creditSection = (CreditSection) 
			formFactory.createEntityDetailSection(EntityDetailType.CREDIT, getConversationHolder(), parent, Section.TWISTIE);
		
		formFactory.createHorizontalSeparator(parent, SWT.BORDER);
		
		ExtensionSection extensionSection = (ExtensionSection) 
			formFactory.createEntityDetailSection(EntityDetailType.EXTENSION, getConversationHolder(), parent, Section.TWISTIE);
		
		formFactory.createHorizontalSeparator(parent, SWT.BORDER);
		
		RightsSection rightsSection = (RightsSection) 
			formFactory.createEntityDetailSection(EntityDetailType.RIGHTS, getConversationHolder(), parent, Section.TWISTIE);
		
		formFactory.createHorizontalSeparator(parent, SWT.BORDER);
		
		SourceSection sourceSection = (SourceSection)
			formFactory.createEntityDetailSection(EntityDetailType.SOURCE, getConversationHolder(), parent, Section.TWISTIE);
		
		formFactory.createHorizontalSeparator(parent, SWT.BORDER);
		
		addPart(creditSection);
		addPart(extensionSection);
		addPart(rightsSection);
		addPart(sourceSection);
		
		if(currentViewPart == VIEW_PART.IdentifiableEntity){
			createVersionSection(parent);
		}
	}
	
	private void createIdentifiableMediaSections(RootElement parent){
		createIdentifiableSections(parent);
		MediaSection mediaSection = (MediaSection) 
			formFactory.createEntityDetailSection(EntityDetailType.MEDIA, getConversationHolder(), parent, Section.TWISTIE);
		
		formFactory.createHorizontalSeparator(parent, SWT.BORDER);
		
		addPart(mediaSection);
		
		if(currentViewPart == VIEW_PART.IdentifiableMediaEntity){
			createVersionSection(parent);
		}
	}
	
	private void createVersionSection(RootElement parent){		
		VersionSection versionSection = formFactory.createVersionSection(parent, Section.NO_TITLE | Section.EXPANDED);
		addPart(versionSection);
	}
	
	/*
	 * (non-Javadoc)
	 * @see org.eclipse.jface.viewers.ISelectionChangedListener#selectionChanged(org.eclipse.jface.viewers.SelectionChangedEvent)
	 */
	/** {@inheritDoc} */
	public void selectionChanged(SelectionChangedEvent event) {
		if(event.getSource() instanceof DetailsViewer){
			if(event.getSelection() == CdmFormFactory.EMPTY_SELECTION){
				setInput(null);
				currentViewPart = VIEW_PART.EMPTY;
				return;
			}
			
			IStructuredSelection selection = (IStructuredSelection) event.getSelection(); 
			setInput(selection.getFirstElement());
		}
	}
}
